/*!
 * Font Awesome Free 7.2.0 by @fontawesome - https://fontawesome.com
 * License - https://fontawesome.com/license/free (Icons: CC BY 4.0, Fonts: SIL OFL 1.1, Code: MIT License)
 * Copyright 2026 Fonticons, Inc.
 */
// Font Awesome core compile (Web Fonts-based)
// -------------------------

@use 'core';
@use 'sizing';
@use 'widths';
@use 'list';
@use 'bordered';
@use 'pulled';
@use 'animated';
@use 'rotated-flipped';
@use 'stacked';
@use 'icons';
