export const faSquareGithub: IconDefinition;
export const faGithubSquare: IconDefinition;
export const faThinkPeaks: IconDefinition;
export const faGoogleDrive: IconDefinition;
export const faAutoprefixer: IconDefinition;
export const faSquareViadeo: IconDefinition;
export const faViadeoSquare: IconDefinition;
export const faCpanel: IconDefinition;
export const faMendeley: IconDefinition;
export const faDraft2digital: IconDefinition;
export const faReplyd: IconDefinition;
export const faEmpire: IconDefinition;
export const faAccessibleIcon: IconDefinition;
export const faQuora: IconDefinition;
export const faCcJcb: IconDefinition;
export const faFedora: IconDefinition;
export const faDuolingo: IconDefinition;
export const faFirstdraft: IconDefinition;
export const faFreebsd: IconDefinition;
export const faOdysee: IconDefinition;
export const faGgCircle: IconDefinition;
export const faCloudflare: IconDefinition;
export const faHackerrank: IconDefinition;
export const faSkyatlas: IconDefinition;
export const faDeskpro: IconDefinition;
export const faResolving: IconDefinition;
export const faBlackberry: IconDefinition;
export const faStripeS: IconDefinition;
export const faSquareBehance: IconDefinition;
export const faBehanceSquare: IconDefinition;
export const faServicestack: IconDefinition;
export const faRocketchat: IconDefinition;
export const faRebel: IconDefinition;
export const faSquareWebAwesome: IconDefinition;
export const faLinktree: IconDefinition;
export const faSimplybuilt: IconDefinition;
export const faStubber: IconDefinition;
export const faApper: IconDefinition;
export const faGoogleScholar: IconDefinition;
export const faYarn: IconDefinition;
export const faStackOverflow: IconDefinition;
export const faBluetooth: IconDefinition;
export const faCreativeCommonsNcJp: IconDefinition;
export const faReddit: IconDefinition;
export const faConnectdevelop: IconDefinition;
export const faResearchgate: IconDefinition;
export const faSignalMessenger: IconDefinition;
export const faXing: IconDefinition;
export const faSquareJs: IconDefinition;
export const faJsSquare: IconDefinition;
export const faFonticons: IconDefinition;
export const faUps: IconDefinition;
export const faAmazonPay: IconDefinition;
export const faPandora: IconDefinition;
export const faOpenid: IconDefinition;
export const faVsco: IconDefinition;
export const faGlobaleaks: IconDefinition;
export const faVenmo: IconDefinition;
export const faUbuntu: IconDefinition;
export const faViacoin: IconDefinition;
export const faZhihu: IconDefinition;
export const faYandex: IconDefinition;
export const faPixiv: IconDefinition;
export const faOpenai: IconDefinition;
export const faSith: IconDefinition;
export const faJulia: IconDefinition;
export const faNfcDirectional: IconDefinition;
export const faCreativeCommonsBy: IconDefinition;
export const faUmbraco: IconDefinition;
export const faHooli: IconDefinition;
export const faSquareGit: IconDefinition;
export const faGitSquare: IconDefinition;
export const faOdnoklassniki: IconDefinition;
export const faDrupal: IconDefinition;
export const faBloggerB: IconDefinition;
export const faInvision: IconDefinition;
export const faFacebookF: IconDefinition;
export const faCentos: IconDefinition;
export const faScaleway: IconDefinition;
export const faCcAmazonPay: IconDefinition;
export const faEbay: IconDefinition;
export const faContao: IconDefinition;
export const faEllo: IconDefinition;
export const faSistrix: IconDefinition;
export const faPeriscope: IconDefinition;
export const faExpeditedssl: IconDefinition;
export const faNapster: IconDefinition;
export const faDelicious: IconDefinition;
export const faGuilded: IconDefinition;
export const faObsidian: IconDefinition;
export const faXbox: IconDefinition;
export const faUntappd: IconDefinition;
export const faGooglePlusG: IconDefinition;
export const faGithubAlt: IconDefinition;
export const faGetPocket: IconDefinition;
export const faGlide: IconDefinition;
export const faBity: IconDefinition;
export const faWpexplorer: IconDefinition;
export const faMegaport: IconDefinition;
export const faLeetcode: IconDefinition;
export const faMdb: IconDefinition;
export const faPage4: IconDefinition;
export const faTheRedYeti: IconDefinition;
export const faJira: IconDefinition;
export const faFedex: IconDefinition;
export const faEvernote: IconDefinition;
export const faUsb: IconDefinition;
export const faAngrycreative: IconDefinition;
export const faMizuni: IconDefinition;
export const faItchIo: IconDefinition;
export const faWindows: IconDefinition;
export const faStumbleupon: IconDefinition;
export const faGoogle: IconDefinition;
export const faDiscord: IconDefinition;
export const faHackerNews: IconDefinition;
export const faEleventy: IconDefinition;
export const fa11ty: IconDefinition;
export const faTeamspeak: IconDefinition;
export const faSupple: IconDefinition;
export const faSquareTwitter: IconDefinition;
export const faTwitterSquare: IconDefinition;
export const faVim: IconDefinition;
export const faFontAwesome: IconDefinition;
export const faFontAwesomeFlag: IconDefinition;
export const faFontAwesomeLogoFull: IconDefinition;
export const faWirsindhandwerk: IconDefinition;
export const faWsh: IconDefinition;
export const faZoom: IconDefinition;
export const faConfluence: IconDefinition;
export const faDigg: IconDefinition;
export const faThreads: IconDefinition;
export const faWpressr: IconDefinition;
export const faRendact: IconDefinition;
export const faYoast: IconDefinition;
export const faNimblr: IconDefinition;
export const faPixelfed: IconDefinition;
export const faYahoo: IconDefinition;
export const faBluesky: IconDefinition;
export const faScribd: IconDefinition;
export const faCreativeCommonsPd: IconDefinition;
export const faEarlybirds: IconDefinition;
export const faSymfonycasts: IconDefinition;
export const faSquareOdnoklassniki: IconDefinition;
export const faOdnoklassnikiSquare: IconDefinition;
export const faMarkdown: IconDefinition;
export const faTypo3: IconDefinition;
export const faJoomla: IconDefinition;
export const faWeixin: IconDefinition;
export const faGrunt: IconDefinition;
export const faSupportnow: IconDefinition;
export const faRockrms: IconDefinition;
export const faUnsplash: IconDefinition;
export const faSquareInstagram: IconDefinition;
export const faInstagramSquare: IconDefinition;
export const faFirstOrderAlt: IconDefinition;
export const faFulcrum: IconDefinition;
export const faArchLinux: IconDefinition;
export const faFediverse: IconDefinition;
export const faBraveReverse: IconDefinition;
export const faAvianex: IconDefinition;
export const faNs8: IconDefinition;
export const faSquarePinterest: IconDefinition;
export const faPinterestSquare: IconDefinition;
export const faBluetoothB: IconDefinition;
export const faGripfire: IconDefinition;
export const faSquareGooglePlus: IconDefinition;
export const faGooglePlusSquare: IconDefinition;
export const faGitee: IconDefinition;
export const faXmpp: IconDefinition;
export const faAppStore: IconDefinition;
export const faWix: IconDefinition;
export const faIntercom: IconDefinition;
export const faReacteurope: IconDefinition;
export const faWaze: IconDefinition;
export const faCreativeCommonsRemix: IconDefinition;
export const faBandcamp: IconDefinition;
export const faSquareWebAwesomeStroke: IconDefinition;
export const faVimeoV: IconDefinition;
export const faStrava: IconDefinition;
export const faUniregistry: IconDefinition;
export const faCcDinersClub: IconDefinition;
export const faKubernetes: IconDefinition;
export const faPinterest: IconDefinition;
export const faAlgolia: IconDefinition;
export const faStackpath: IconDefinition;
export const faOctopusDeploy: IconDefinition;
export const faYammer: IconDefinition;
export const faModx: IconDefinition;
export const faSquareThreads: IconDefinition;
export const faOldRepublic: IconDefinition;
export const faSuse: IconDefinition;
export const faAppStoreIos: IconDefinition;
export const faUltralyticsYolo: IconDefinition;
export const faSquareDribbble: IconDefinition;
export const faDribbbleSquare: IconDefinition;
export const faUikit: IconDefinition;
export const faSuperpowers: IconDefinition;
export const faYoutube: IconDefinition;
export const faEmber: IconDefinition;
export const faBootstrap: IconDefinition;
export const faItunes: IconDefinition;
export const faSquareXing: IconDefinition;
export const faXingSquare: IconDefinition;
export const faCss3Alt: IconDefinition;
export const faSquarespace: IconDefinition;
export const faTrello: IconDefinition;
export const faViadeo: IconDefinition;
export const faSearchengin: IconDefinition;
export const faUnrealEngine: IconDefinition;
export const faPaypal: IconDefinition;
export const faSquareBluesky: IconDefinition;
export const faDAndDBeyond: IconDefinition;
export const faMicrosoft: IconDefinition;
export const faFly: IconDefinition;
export const faCcStripe: IconDefinition;
export const faWordpressSimple: IconDefinition;
export const faSellsy: IconDefinition;
export const faDashcube: IconDefinition;
export const faGitter: IconDefinition;
export const faWolfPackBattalion: IconDefinition;
export const faLastfm: IconDefinition;
export const faShopware: IconDefinition;
export const faBlogger: IconDefinition;
export const faEdge: IconDefinition;
export const faIoxhost: IconDefinition;
export const faSchlix: IconDefinition;
export const faDAndD: IconDefinition;
export const faVuejs: IconDefinition;
export const faMeta: IconDefinition;
export const faCreativeCommonsShare: IconDefinition;
export const faStudiovinari: IconDefinition;
export const faBitbucket: IconDefinition;
export const faVk: IconDefinition;
export const faGithub: IconDefinition;
export const faCodiepie: IconDefinition;
export const faPiedPiper: IconDefinition;
export const faRaspberryPi: IconDefinition;
export const faCss3: IconDefinition;
export const faHubspot: IconDefinition;
export const faCmplid: IconDefinition;
export const faDyalog: IconDefinition;
export const faElementor: IconDefinition;
export const faFirstOrder: IconDefinition;
export const faDribbble: IconDefinition;
export const faLinkedin: IconDefinition;
export const faCcPaypal: IconDefinition;
export const faDhl: IconDefinition;
export const faTex: IconDefinition;
export const faClaude: IconDefinition;
export const faShopify: IconDefinition;
export const faSquareReddit: IconDefinition;
export const faRedditSquare: IconDefinition;
export const faCreativeCommonsNc: IconDefinition;
export const faGalacticRepublic: IconDefinition;
export const faFacebook: IconDefinition;
export const faGitlab: IconDefinition;
export const faQq: IconDefinition;
export const faStripe: IconDefinition;
export const faDailymotion: IconDefinition;
export const faSteam: IconDefinition;
export const faVenmoV: IconDefinition;
export const faSnapchat: IconDefinition;
export const faSnapchatGhost: IconDefinition;
export const faGalacticSenate: IconDefinition;
export const faPhoenixFramework: IconDefinition;
export const faGit: IconDefinition;
export const faOptinMonster: IconDefinition;
export const faJenkins: IconDefinition;
export const faSlideshare: IconDefinition;
export const faUber: IconDefinition;
export const faDigitalOcean: IconDefinition;
export const faSoundcloud: IconDefinition;
export const faSquareFigma: IconDefinition;
export const faCreativeCommonsSa: IconDefinition;
export const faChrome: IconDefinition;
export const faTradeFederation: IconDefinition;
export const faVaadin: IconDefinition;
export const faDeviantart: IconDefinition;
export const faMedium: IconDefinition;
export const faMediumM: IconDefinition;
export const faOpencart: IconDefinition;
export const faYCombinator: IconDefinition;
export const faLine: IconDefinition;
export const faAmilia: IconDefinition;
export const faAsymmetrik: IconDefinition;
export const faPhabricator: IconDefinition;
export const faBots: IconDefinition;
export const faVine: IconDefinition;
export const faMedrt: IconDefinition;
export const faOsi: IconDefinition;
export const faGg: IconDefinition;
export const faBuysellads: IconDefinition;
export const faGooglePlus: IconDefinition;
export const faScreenpal: IconDefinition;
export const faBitcoin: IconDefinition;
export const faSwift: IconDefinition;
export const faFilesPinwheel: IconDefinition;
export const faLaravel: IconDefinition;
export const faWpforms: IconDefinition;
export const faSpeakerDeck: IconDefinition;
export const faFlickr: IconDefinition;
export const faCcVisa: IconDefinition;
export const faUpwork: IconDefinition;
export const faKakaoTalk: IconDefinition;
export const faFlutter: IconDefinition;
export const faBuffer: IconDefinition;
export const faGratipay: IconDefinition;
export const faGooglePay: IconDefinition;
export const faApple: IconDefinition;
export const faTumblr: IconDefinition;
export const faPhoenixSquadron: IconDefinition;
export const faCentercode: IconDefinition;
export const faDebian: IconDefinition;
export const faMastodon: IconDefinition;
export const faSketch: IconDefinition;
export const faWebAwesome: IconDefinition;
export const faSass: IconDefinition;
export const faThreema: IconDefinition;
export const faSquareWhatsapp: IconDefinition;
export const faWhatsappSquare: IconDefinition;
export const faSkype: IconDefinition;
export const faAngular: IconDefinition;
export const faCircleZulip: IconDefinition;
export const faOpensuse: IconDefinition;
export const faDropbox: IconDefinition;
export const faDeezer: IconDefinition;
export const faCreativeCommonsSampling: IconDefinition;
export const faJediOrder: IconDefinition;
export const faRProject: IconDefinition;
export const faInstalod: IconDefinition;
export const faCanadianMapleLeaf: IconDefinition;
export const faEthereum: IconDefinition;
export const faHouzz: IconDefinition;
export const faViber: IconDefinition;
export const faKickstarter: IconDefinition;
export const faSquareKickstarter: IconDefinition;
export const faSpotify: IconDefinition;
export const faLeanpub: IconDefinition;
export const faJava: IconDefinition;
export const faNfcSymbol: IconDefinition;
export const faWodu: IconDefinition;
export const faSquareSteam: IconDefinition;
export const faSteamSquare: IconDefinition;
export const faCreativeCommonsNcEu: IconDefinition;
export const faNpm: IconDefinition;
export const faCloudscale: IconDefinition;
export const faThemeco: IconDefinition;
export const faGooglePlay: IconDefinition;
export const faKorvue: IconDefinition;
export const faW3c: IconDefinition;
export const faGrav: IconDefinition;
export const faAws: IconDefinition;
export const faGlideG: IconDefinition;
export const faJsfiddle: IconDefinition;
export const faKeybase: IconDefinition;
export const faLumonDrop: IconDefinition;
export const faForgejo: IconDefinition;
export const faPostgresql: IconDefinition;
export const faWeebly: IconDefinition;
export const faDocker: IconDefinition;
export const faMagento: IconDefinition;
export const faTorBrowser: IconDefinition;
export const faGitAlt: IconDefinition;
export const faFirefoxBrowser: IconDefinition;
export const faCloudsmith: IconDefinition;
export const faWizardsOfTheCoast: IconDefinition;
export const faCreativeCommonsNd: IconDefinition;
export const faUsps: IconDefinition;
export const faSquareLetterboxd: IconDefinition;
export const faMandalorian: IconDefinition;
export const faSlack: IconDefinition;
export const faSlackHash: IconDefinition;
export const faAngellist: IconDefinition;
export const faAndroid: IconDefinition;
export const faMeetup: IconDefinition;
export const faFonticonsFi: IconDefinition;
export const faPalfed: IconDefinition;
export const faWpbeginner: IconDefinition;
export const faDiaspora: IconDefinition;
export const faProductHunt: IconDefinition;
export const faSquareUpwork: IconDefinition;
export const faCuttlefish: IconDefinition;
export const faMedapps: IconDefinition;
export const faPix: IconDefinition;
export const faSquareTumblr: IconDefinition;
export const faTumblrSquare: IconDefinition;
export const faReact: IconDefinition;
export const faHuggingFace: IconDefinition;
export const faJxl: IconDefinition;
export const faSquareLinkedin: IconDefinition;
export const faCss: IconDefinition;
export const faHashnode: IconDefinition;
export const faRedditAlien: IconDefinition;
export const faTiktok: IconDefinition;
export const faWordpress: IconDefinition;
export const faIdeal: IconDefinition;
export const faPiedPiperPp: IconDefinition;
export const faUssunnah: IconDefinition;
export const faFortAwesomeAlt: IconDefinition;
export const faBuromobelexperte: IconDefinition;
export const faBilibili: IconDefinition;
export const faNeos: IconDefinition;
export const faDev: IconDefinition;
export const faHotjar: IconDefinition;
export const faDochub: IconDefinition;
export const faVimeo: IconDefinition;
export const faMaxcdn: IconDefinition;
export const faSquareFontAwesomeStroke: IconDefinition;
export const faFontAwesomeAlt: IconDefinition;
export const faSpeakap: IconDefinition;
export const faFantasyFlightGames: IconDefinition;
export const faLinux: IconDefinition;
export const faCottonBureau: IconDefinition;
export const faGoogleWallet: IconDefinition;
export const faFoursquare: IconDefinition;
export const faShirtsinbulk: IconDefinition;
export const faMintbit: IconDefinition;
export const faZulip: IconDefinition;
export const faStaylinked: IconDefinition;
export const faWebflow: IconDefinition;
export const faRenren: IconDefinition;
export const faKoFi: IconDefinition;
export const faRev: IconDefinition;
export const faKeycdn: IconDefinition;
export const faHireAHelper: IconDefinition;
export const faSquareHackerNews: IconDefinition;
export const faHackerNewsSquare: IconDefinition;
export const faCreativeCommonsPdAlt: IconDefinition;
export const faOrcid: IconDefinition;
export const faBoardGameGeek: IconDefinition;
export const faBgg: IconDefinition;
export const faBehance: IconDefinition;
export const faMonero: IconDefinition;
export const faFigma: IconDefinition;
export const faInstagram: IconDefinition;
export const faPerbyte: IconDefinition;
export const faSquareVimeo: IconDefinition;
export const faVimeoSquare: IconDefinition;
export const faPushed: IconDefinition;
export const faMixcloud: IconDefinition;
export const faYandexInternational: IconDefinition;
export const faHive: IconDefinition;
export const faCreativeCommonsZero: IconDefinition;
export const faSquareSnapchat: IconDefinition;
export const faSnapchatSquare: IconDefinition;
export const faThemeisle: IconDefinition;
export const faDartLang: IconDefinition;
export const faDeploydog: IconDefinition;
export const faFlipboard: IconDefinition;
export const faBuyNLarge: IconDefinition;
export const faWatchmanMonitoring: IconDefinition;
export const faHips: IconDefinition;
export const faCloudversify: IconDefinition;
export const faGoodreads: IconDefinition;
export const faTidal: IconDefinition;
export const faUnity: IconDefinition;
export const faTencentWeibo: IconDefinition;
export const faFreeCodeCamp: IconDefinition;
export const faXTwitter: IconDefinition;
export const faStickerMule: IconDefinition;
export const faTwitch: IconDefinition;
export const faKickstarterK: IconDefinition;
export const faCriticalRole: IconDefinition;
export const faSteamSymbol: IconDefinition;
export const faMailchimp: IconDefinition;
export const faLumon: IconDefinition;
export const faNutritionix: IconDefinition;
export const faCreativeCommonsSamplingPlus: IconDefinition;
export const faRedhat: IconDefinition;
export const faSquarePiedPiper: IconDefinition;
export const faPiedPiperSquare: IconDefinition;
export const faWhatsapp: IconDefinition;
export const faImdb: IconDefinition;
export const faPython: IconDefinition;
export const faCashApp: IconDefinition;
export const faPinterestP: IconDefinition;
export const faWhmcs: IconDefinition;
export const faJoget: IconDefinition;
export const faSquareYoutube: IconDefinition;
export const faYoutubeSquare: IconDefinition;
export const faAtlassian: IconDefinition;
export const faPiedPiperHat: IconDefinition;
export const faInternetExplorer: IconDefinition;
export const faAirbnb: IconDefinition;
export const faJs: IconDefinition;
export const faQuinscape: IconDefinition;
export const faAdversal: IconDefinition;
export const faCreativeCommons: IconDefinition;
export const faNotion: IconDefinition;
export const faChromecast: IconDefinition;
export const faUltralyticsHub: IconDefinition;
export const faWikipediaW: IconDefinition;
export const faSitrox: IconDefinition;
export const faSquareGitlab: IconDefinition;
export const faGitlabSquare: IconDefinition;
export const faShoelace: IconDefinition;
export const faOpenstreetmap: IconDefinition;
export const faSellcast: IconDefinition;
export const faMix: IconDefinition;
export const faCcApplePay: IconDefinition;
export const faSolana: IconDefinition;
export const faTypescript: IconDefinition;
export const faBrave: IconDefinition;
export const faEtsy: IconDefinition;
export const faBtc: IconDefinition;
export const faAdn: IconDefinition;
export const faSquareXTwitter: IconDefinition;
export const faSquareFontAwesome: IconDefinition;
export const faForumbee: IconDefinition;
export const fa42Group: IconDefinition;
export const faInnosoft: IconDefinition;
export const faStumbleuponCircle: IconDefinition;
export const faSymfony: IconDefinition;
export const faSalesforce: IconDefinition;
export const faSourcetree: IconDefinition;
export const faLinkedinIn: IconDefinition;
export const faHtml5: IconDefinition;
export const faRust: IconDefinition;
export const faHornbill: IconDefinition;
export const faPhp: IconDefinition;
export const faDisqus: IconDefinition;
export const fa500px: IconDefinition;
export const faAffiliatetheme: IconDefinition;
export const faRedRiver: IconDefinition;
export const faTwitter: IconDefinition;
export const faFortAwesome: IconDefinition;
export const faMixer: IconDefinition;
export const faLyft: IconDefinition;
export const faApplePay: IconDefinition;
export const faArtstation: IconDefinition;
export const faNodeJs: IconDefinition;
export const faUncharted: IconDefinition;
export const faPlaystation: IconDefinition;
export const faMicroblog: IconDefinition;
export const faGitkraken: IconDefinition;
export const faTelegram: IconDefinition;
export const faTelegramPlane: IconDefinition;
export const faUltralytics: IconDefinition;
export const faItunesNote: IconDefinition;
export const faLess: IconDefinition;
export const faFirefox: IconDefinition;
export const faKaggle: IconDefinition;
export const faFacebookMessenger: IconDefinition;
export const faAudible: IconDefinition;
export const faPatreon: IconDefinition;
export const faVnv: IconDefinition;
export const faPagelines: IconDefinition;
export const faAmazon: IconDefinition;
export const faEnvira: IconDefinition;
export const faLinode: IconDefinition;
export const faAccusoft: IconDefinition;
export const faErlang: IconDefinition;
export const faUnison: IconDefinition;
export const faCcDiscover: IconDefinition;
export const faSafari: IconDefinition;
export const faSpaceAwesome: IconDefinition;
export const faNode: IconDefinition;
export const faCodepen: IconDefinition;
export const faRavelry: IconDefinition;
export const faAlipay: IconDefinition;
export const faCcAmex: IconDefinition;
export const faPiedPiperAlt: IconDefinition;
export const faLetterboxd: IconDefinition;
export const faOpera: IconDefinition;
export const faWeibo: IconDefinition;
export const faReadme: IconDefinition;
export const faGolang: IconDefinition;
export const faStackExchange: IconDefinition;
export const faGulp: IconDefinition;
export const faYelp: IconDefinition;
export const faGofore: IconDefinition;
export const faAviato: IconDefinition;
export const faPadlet: IconDefinition;
export const faEdgeLegacy: IconDefinition;
export const faSquareLastfm: IconDefinition;
export const faLastfmSquare: IconDefinition;
export const faGoodreadsG: IconDefinition;
export const faCcMastercard: IconDefinition;
export const faDiscourse: IconDefinition;
export const faBlackTie: IconDefinition;
export const faSquareFacebook: IconDefinition;
export const faFacebookSquare: IconDefinition;
export const faBattleNet: IconDefinition;
export const faBimobject: IconDefinition;
export const faSvelte: IconDefinition;
export const faSquareDeskpro: IconDefinition;
export const faTailwindCss: IconDefinition;
import { IconDefinition, IconLookup, IconName, IconPrefix, IconPack } from '@fortawesome/fontawesome-common-types';
export { IconDefinition, IconLookup, IconName, IconPrefix, IconPack } from '@fortawesome/fontawesome-common-types';
export const prefix: IconPrefix;
export const fab: IconPack;