export const fa0: IconDefinition;
export const fa1: IconDefinition;
export const fa2: IconDefinition;
export const fa3: IconDefinition;
export const fa4: IconDefinition;
export const fa5: IconDefinition;
export const fa6: IconDefinition;
export const fa7: IconDefinition;
export const fa8: IconDefinition;
export const fa9: IconDefinition;
export const faDollarSign: IconDefinition;
export const faDollar: IconDefinition;
export const faUsd: IconDefinition;
export const faDog: IconDefinition;
export const faTruckMoving: IconDefinition;
export const faRotate: IconDefinition;
export const faSyncAlt: IconDefinition;
export const faSquareMinus: IconDefinition;
export const faMinusSquare: IconDefinition;
export const faAlignJustify: IconDefinition;
export const faCalendarCheck: IconDefinition;
export const faFaceKiss: IconDefinition;
export const faKiss: IconDefinition;
export const faKitchenSet: IconDefinition;
export const faDna: IconDefinition;
export const faChildReaching: IconDefinition;
export const faPaste: IconDefinition;
export const faFileClipboard: IconDefinition;
export const faMeteor: IconDefinition;
export const faGears: IconDefinition;
export const faCogs: IconDefinition;
export const faFileCirclePlus: IconDefinition;
export const faIcicles: IconDefinition;
export const faArrowTrendUp: IconDefinition;
export const faHexagonNodesBolt: IconDefinition;
export const faQuestion: IconDefinition;
export const faHandsBound: IconDefinition;
export const faPersonWalkingLuggage: IconDefinition;
export const faFileArrowDown: IconDefinition;
export const faFileDownload: IconDefinition;
export const faPersonBooth: IconDefinition;
export const faLocust: IconDefinition;
export const faRightLong: IconDefinition;
export const faLongArrowAltRight: IconDefinition;
export const faTruckDroplet: IconDefinition;
export const faHandHoldingMedical: IconDefinition;
export const faHandPointLeft: IconDefinition;
export const faCalculator: IconDefinition;
export const faMinus: IconDefinition;
export const faSubtract: IconDefinition;
export const faArrowUpZA: IconDefinition;
export const faSortAlphaUpAlt: IconDefinition;
export const faMicrophoneSlash: IconDefinition;
export const faSquarePen: IconDefinition;
export const faPenSquare: IconDefinition;
export const faPencilSquare: IconDefinition;
export const faHandFist: IconDefinition;
export const faFistRaised: IconDefinition;
export const faCommentSms: IconDefinition;
export const faSms: IconDefinition;
export const faSimCard: IconDefinition;
export const faScaleBalanced: IconDefinition;
export const faBalanceScale: IconDefinition;
export const faCar: IconDefinition;
export const faAutomobile: IconDefinition;
export const faCropSimple: IconDefinition;
export const faCropAlt: IconDefinition;
export const faMedal: IconDefinition;
export const faScroll: IconDefinition;
export const faFileExcel: IconDefinition;
export const faFilter: IconDefinition;
export const faDrum: IconDefinition;
export const faMapPin: IconDefinition;
export const faScaleUnbalancedFlip: IconDefinition;
export const faBalanceScaleRight: IconDefinition;
export const faArrowsToCircle: IconDefinition;
export const faEnvelope: IconDefinition;
export const faBaby: IconDefinition;
export const faSquareCaretDown: IconDefinition;
export const faCaretSquareDown: IconDefinition;
export const faTent: IconDefinition;
export const faA: IconDefinition;
export const faParachuteBox: IconDefinition;
export const faCartArrowDown: IconDefinition;
export const faBridgeCircleExclamation: IconDefinition;
export const faCloudArrowUp: IconDefinition;
export const faCloudUpload: IconDefinition;
export const faCloudUploadAlt: IconDefinition;
export const faAt: IconDefinition;
export const faIndianRupeeSign: IconDefinition;
export const faIndianRupee: IconDefinition;
export const faInr: IconDefinition;
export const faTruck: IconDefinition;
export const faChalkboardUser: IconDefinition;
export const faChalkboardTeacher: IconDefinition;
export const faUserCheck: IconDefinition;
export const faUserNinja: IconDefinition;
export const faPlantWilt: IconDefinition;
export const faWeightScale: IconDefinition;
export const faWeight: IconDefinition;
export const faCaretRight: IconDefinition;
export const faFlorinSign: IconDefinition;
export const faBell: IconDefinition;
export const faLariSign: IconDefinition;
export const faMillSign: IconDefinition;
export const faPersonSnowboarding: IconDefinition;
export const faSnowboarding: IconDefinition;
export const faTty: IconDefinition;
export const faTeletype: IconDefinition;
export const faUsersRectangle: IconDefinition;
export const faMobile: IconDefinition;
export const faMobileAndroid: IconDefinition;
export const faMobilePhone: IconDefinition;
export const faArrowsTurnToDots: IconDefinition;
export const faExclamation: IconDefinition;
export const faChurch: IconDefinition;
export const faToggleOff: IconDefinition;
export const faShoePrints: IconDefinition;
export const faFileCircleExclamation: IconDefinition;
export const faWallet: IconDefinition;
export const faMessage: IconDefinition;
export const faCommentAlt: IconDefinition;
export const faTrophy: IconDefinition;
export const faFaceDizzy: IconDefinition;
export const faDizzy: IconDefinition;
export const faBacteria: IconDefinition;
export const faEarDeaf: IconDefinition;
export const faDeaf: IconDefinition;
export const faDeafness: IconDefinition;
export const faHardOfHearing: IconDefinition;
export const faPeopleArrows: IconDefinition;
export const faPeopleArrowsLeftRight: IconDefinition;
export const faHandsClapping: IconDefinition;
export const faVirusCovidSlash: IconDefinition;
export const faCalendarDays: IconDefinition;
export const faCalendarAlt: IconDefinition;
export const faDiamondTurnRight: IconDefinition;
export const faDirections: IconDefinition;
export const faHandPointUp: IconDefinition;
export const faBezierCurve: IconDefinition;
export const faPersonHalfDress: IconDefinition;
export const faSquarePollHorizontal: IconDefinition;
export const faPollH: IconDefinition;
export const faSchoolCircleXmark: IconDefinition;
export const faHandLizard: IconDefinition;
export const faChalkboard: IconDefinition;
export const faBlackboard: IconDefinition;
export const faUpRightFromSquare: IconDefinition;
export const faExternalLinkAlt: IconDefinition;
export const faSquareFull: IconDefinition;
export const faClover: IconDefinition;
export const faTeethOpen: IconDefinition;
export const faBarsStaggered: IconDefinition;
export const faReorder: IconDefinition;
export const faStream: IconDefinition;
export const faWarehouse: IconDefinition;
export const faSwatchbook: IconDefinition;
export const faCampground: IconDefinition;
export const faPersonWalkingArrowRight: IconDefinition;
export const faGlasses: IconDefinition;
export const faCirclePause: IconDefinition;
export const faPauseCircle: IconDefinition;
export const faMemory: IconDefinition;
export const faGift: IconDefinition;
export const faMoneyBillWheat: IconDefinition;
export const faDungeon: IconDefinition;
export const faSuitcaseMedical: IconDefinition;
export const faMedkit: IconDefinition;
export const faPersonCane: IconDefinition;
export const faGauge: IconDefinition;
export const faDashboard: IconDefinition;
export const faGaugeMed: IconDefinition;
export const faTachometerAltAverage: IconDefinition;
export const faEnvelopeOpenText: IconDefinition;
export const faToolbox: IconDefinition;
export const faPowerOff: IconDefinition;
export const faSignal: IconDefinition;
export const faSignal5: IconDefinition;
export const faSignalPerfect: IconDefinition;
export const faArrowsSpin: IconDefinition;
export const faJoint: IconDefinition;
export const faBraille: IconDefinition;
export const faBasketShopping: IconDefinition;
export const faShoppingBasket: IconDefinition;
export const faBridge: IconDefinition;
export const faPlaneArrival: IconDefinition;
export const faCashRegister: IconDefinition;
export const faRing: IconDefinition;
export const faAquarius: IconDefinition;
export const faShareNodes: IconDefinition;
export const faShareAlt: IconDefinition;
export const faPersonCircleExclamation: IconDefinition;
export const faBinoculars: IconDefinition;
export const faKipSign: IconDefinition;
export const faHardDrive: IconDefinition;
export const faHdd: IconDefinition;
export const faRankingStar: IconDefinition;
export const faUserTie: IconDefinition;
export const faEllipsis: IconDefinition;
export const faEllipsisH: IconDefinition;
export const faStoreSlash: IconDefinition;
export const faPercent: IconDefinition;
export const faPercentage: IconDefinition;
export const faFileZipper: IconDefinition;
export const faFileArchive: IconDefinition;
export const faDisplay: IconDefinition;
export const faIcons: IconDefinition;
export const faHeartMusicCameraBolt: IconDefinition;
export const faRulerVertical: IconDefinition;
export const faMapLocationDot: IconDefinition;
export const faMapMarkedAlt: IconDefinition;
export const faHeartCrack: IconDefinition;
export const faHeartBroken: IconDefinition;
export const faCow: IconDefinition;
export const faRss: IconDefinition;
export const faFeed: IconDefinition;
export const faMagnifyingGlass: IconDefinition;
export const faSearch: IconDefinition;
export const faCloudMoon: IconDefinition;
export const faBoxesStacked: IconDefinition;
export const faBoxes: IconDefinition;
export const faBoxesAlt: IconDefinition;
export const faCodeBranch: IconDefinition;
export const faBan: IconDefinition;
export const faCancel: IconDefinition;
export const faJugDetergent: IconDefinition;
export const faReply: IconDefinition;
export const faMailReply: IconDefinition;
export const faSunPlantWilt: IconDefinition;
export const faBacterium: IconDefinition;
export const faRecordVinyl: IconDefinition;
export const faFloppyDisk: IconDefinition;
export const faSave: IconDefinition;
export const faToiletsPortable: IconDefinition;
export const faO: IconDefinition;
export const faPalette: IconDefinition;
export const faUnlock: IconDefinition;
export const faEarListen: IconDefinition;
export const faAssistiveListeningSystems: IconDefinition;
export const faCodePullRequest: IconDefinition;
export const faKey: IconDefinition;
export const faSkull: IconDefinition;
export const faMarsStrokeUp: IconDefinition;
export const faMarsStrokeV: IconDefinition;
export const faFireFlameSimple: IconDefinition;
export const faBurn: IconDefinition;
export const faTree: IconDefinition;
export const faSmog: IconDefinition;
export const faS: IconDefinition;
export const faJedi: IconDefinition;
export const faPersonHiking: IconDefinition;
export const faHiking: IconDefinition;
export const faArrowsUpToLine: IconDefinition;
export const faMarsDouble: IconDefinition;
export const faThermometer: IconDefinition;
export const faPaintbrush: IconDefinition;
export const faPaintBrush: IconDefinition;
export const faNeuter: IconDefinition;
export const faSquarePhoneFlip: IconDefinition;
export const faPhoneSquareAlt: IconDefinition;
export const faFaceGrinTongueSquint: IconDefinition;
export const faGrinTongueSquint: IconDefinition;
export const faCommentDollar: IconDefinition;
export const faHippo: IconDefinition;
export const faBowlFood: IconDefinition;
export const faSquareVirus: IconDefinition;
export const faCloudSunRain: IconDefinition;
export const faArrowRightLong: IconDefinition;
export const faLongArrowRight: IconDefinition;
export const faBuildingUn: IconDefinition;
export const faTemperatureLow: IconDefinition;
export const faDoorOpen: IconDefinition;
export const faAlignLeft: IconDefinition;
export const faCamera: IconDefinition;
export const faCameraAlt: IconDefinition;
export const faUsersRays: IconDefinition;
export const faRainbow: IconDefinition;
export const faSitemap: IconDefinition;
export const faFaceGrinStars: IconDefinition;
export const faGrinStars: IconDefinition;
export const faSortUp: IconDefinition;
export const faSortAsc: IconDefinition;
export const faEye: IconDefinition;
export const faCaretLeft: IconDefinition;
export const faAppleWhole: IconDefinition;
export const faAppleAlt: IconDefinition;
export const faScrollTorah: IconDefinition;
export const faTorah: IconDefinition;
export const faHouseLock: IconDefinition;
export const faArrowsLeftRightToLine: IconDefinition;
export const faTrash: IconDefinition;
export const faFaceSadTear: IconDefinition;
export const faSadTear: IconDefinition;
export const faFax: IconDefinition;
export const faPersonCirclePlus: IconDefinition;
export const faHamsa: IconDefinition;
export const faPersonCircleQuestion: IconDefinition;
export const faClipboardCheck: IconDefinition;
export const faShareFromSquare: IconDefinition;
export const faShareSquare: IconDefinition;
export const faReceipt: IconDefinition;
export const faEquals: IconDefinition;
export const faChevronUp: IconDefinition;
export const faVirusSlash: IconDefinition;
export const faSlash: IconDefinition;
export const faExpand: IconDefinition;
export const faNoteSticky: IconDefinition;
export const faStickyNote: IconDefinition;
export const faTableColumns: IconDefinition;
export const faColumns: IconDefinition;
export const faPersonShelter: IconDefinition;
export const faCircleNotch: IconDefinition;
export const faWater: IconDefinition;
export const faDeleteLeft: IconDefinition;
export const faBackspace: IconDefinition;
export const faBroomBall: IconDefinition;
export const faQuidditch: IconDefinition;
export const faQuidditchBroomBall: IconDefinition;
export const faJ: IconDefinition;
export const faShuttleSpace: IconDefinition;
export const faSpaceShuttle: IconDefinition;
export const faYinYang: IconDefinition;
export const faStop: IconDefinition;
export const faTrowel: IconDefinition;
export const faHandBackFist: IconDefinition;
export const faHandRock: IconDefinition;
export const faTemperatureHigh: IconDefinition;
export const faGreaterThan: IconDefinition;
export const faCrutch: IconDefinition;
export const faSeptagon: IconDefinition;
export const faHeptagon: IconDefinition;
export const faStreetView: IconDefinition;
export const faWaveSquare: IconDefinition;
export const faAngleLeft: IconDefinition;
export const faScrewdriver: IconDefinition;
export const faTractor: IconDefinition;
export const faBridgeCircleXmark: IconDefinition;
export const faVials: IconDefinition;
export const faStethoscope: IconDefinition;
export const faPodcast: IconDefinition;
export const faArrowUpRightDots: IconDefinition;
export const faChessQueen: IconDefinition;
export const faAnchorCircleExclamation: IconDefinition;
export const faEllipsisVertical: IconDefinition;
export const faEllipsisV: IconDefinition;
export const faHeartCircleExclamation: IconDefinition;
export const faBuildingCircleExclamation: IconDefinition;
export const faPersonArrowUpFromLine: IconDefinition;
export const faNotEqual: IconDefinition;
export const faTrainTram: IconDefinition;
export const faPlaneDeparture: IconDefinition;
export const faRightToBracket: IconDefinition;
export const faSignInAlt: IconDefinition;
export const faSdCard: IconDefinition;
export const faHouseCircleExclamation: IconDefinition;
export const faShekelSign: IconDefinition;
export const faIls: IconDefinition;
export const faShekel: IconDefinition;
export const faSheqel: IconDefinition;
export const faSheqelSign: IconDefinition;
export const faRadio: IconDefinition;
export const faHandDots: IconDefinition;
export const faAllergies: IconDefinition;
export const faBookSkull: IconDefinition;
export const faBookDead: IconDefinition;
export const faUnlockKeyhole: IconDefinition;
export const faUnlockAlt: IconDefinition;
export const faFileArrowUp: IconDefinition;
export const faFileUpload: IconDefinition;
export const faFaceGrinTears: IconDefinition;
export const faGrinTears: IconDefinition;
export const faPenToSquare: IconDefinition;
export const faEdit: IconDefinition;
export const faEarthEurope: IconDefinition;
export const faGlobeEurope: IconDefinition;
export const faFaceGrinBeamSweat: IconDefinition;
export const faGrinBeamSweat: IconDefinition;
export const faCircleHalfStroke: IconDefinition;
export const faAdjust: IconDefinition;
export const faPersonMilitaryToPerson: IconDefinition;
export const faTableCellsColumnLock: IconDefinition;
export const faTruckFieldUn: IconDefinition;
export const faClock: IconDefinition;
export const faClockFour: IconDefinition;
export const faBook: IconDefinition;
export const faFaceLaughWink: IconDefinition;
export const faLaughWink: IconDefinition;
export const faCloudMeatball: IconDefinition;
export const faChartArea: IconDefinition;
export const faAreaChart: IconDefinition;
export const faRupiahSign: IconDefinition;
export const faTextWidth: IconDefinition;
export const faSatellite: IconDefinition;
export const faMagnifyingGlassMinus: IconDefinition;
export const faSearchMinus: IconDefinition;
export const faPeopleGroup: IconDefinition;
export const faSquareBinary: IconDefinition;
export const faMasksTheater: IconDefinition;
export const faTheaterMasks: IconDefinition;
export const faCartPlus: IconDefinition;
export const faHandsAslInterpreting: IconDefinition;
export const faAmericanSignLanguageInterpreting: IconDefinition;
export const faAslInterpreting: IconDefinition;
export const faHandsAmericanSignLanguageInterpreting: IconDefinition;
export const faTableCellsRowUnlock: IconDefinition;
export const faRocket: IconDefinition;
export const faShrimp: IconDefinition;
export const faTengeSign: IconDefinition;
export const faTenge: IconDefinition;
export const faHouseChimneyMedical: IconDefinition;
export const faClinicMedical: IconDefinition;
export const faUsersSlash: IconDefinition;
export const faPaperPlane: IconDefinition;
export const faBookAtlas: IconDefinition;
export const faAtlas: IconDefinition;
export const faTable: IconDefinition;
export const faHeart: IconDefinition;
export const faCircleChevronUp: IconDefinition;
export const faChevronCircleUp: IconDefinition;
export const faBatteryHalf: IconDefinition;
export const faBattery3: IconDefinition;
export const faFontAwesome: IconDefinition;
export const faFontAwesomeFlag: IconDefinition;
export const faFontAwesomeLogoFull: IconDefinition;
export const faHandcuffs: IconDefinition;
export const faHatCowboySide: IconDefinition;
export const faIndustry: IconDefinition;
export const faLinesLeaning: IconDefinition;
export const faPassport: IconDefinition;
export const faInfinity: IconDefinition;
export const faClone: IconDefinition;
export const faForward: IconDefinition;
export const faM: IconDefinition;
export const faRoadSpikes: IconDefinition;
export const faMountain: IconDefinition;
export const faChess: IconDefinition;
export const faTemperatureThreeQuarters: IconDefinition;
export const faTemperature3: IconDefinition;
export const faThermometer3: IconDefinition;
export const faThermometerThreeQuarters: IconDefinition;
export const faB: IconDefinition;
export const faShieldVirus: IconDefinition;
export const faLitecoinSign: IconDefinition;
export const faDiceD6: IconDefinition;
export const faGripLinesVertical: IconDefinition;
export const faGolfBallTee: IconDefinition;
export const faGolfBall: IconDefinition;
export const faHexagon: IconDefinition;
export const faFolderOpen: IconDefinition;
export const faKaaba: IconDefinition;
export const faHandHolding: IconDefinition;
export const faSingleQuoteRight: IconDefinition;
export const faBottleDroplet: IconDefinition;
export const faWindowMinimize: IconDefinition;
export const faChevronRight: IconDefinition;
export const faEgg: IconDefinition;
export const faLandmarkDome: IconDefinition;
export const faLandmarkAlt: IconDefinition;
export const faWorm: IconDefinition;
export const faUserInjured: IconDefinition;
export const faStrikethrough: IconDefinition;
export const faBlog: IconDefinition;
export const faStopwatch20: IconDefinition;
export const faTruckPickup: IconDefinition;
export const faSeedling: IconDefinition;
export const faSprout: IconDefinition;
export const faTransgender: IconDefinition;
export const faTransgenderAlt: IconDefinition;
export const faStarHalf: IconDefinition;
export const faPhotoFilm: IconDefinition;
export const faPhotoVideo: IconDefinition;
export const faPictureInPicture: IconDefinition;
export const faPumpMedical: IconDefinition;
export const faFire: IconDefinition;
export const faMagnifyingGlassPlus: IconDefinition;
export const faSearchPlus: IconDefinition;
export const faFlask: IconDefinition;
export const faAlignRight: IconDefinition;
export const faCableCar: IconDefinition;
export const faTram: IconDefinition;
export const faKitMedical: IconDefinition;
export const faFirstAid: IconDefinition;
export const faGripLines: IconDefinition;
export const faBurger: IconDefinition;
export const faHamburger: IconDefinition;
export const faSnowman: IconDefinition;
export const faHotel: IconDefinition;
export const faPrint: IconDefinition;
export const faVolleyball: IconDefinition;
export const faVolleyballBall: IconDefinition;
export const faTrafficLight: IconDefinition;
export const faPlaneCircleCheck: IconDefinition;
export const faUsers: IconDefinition;
export const faCertificate: IconDefinition;
export const faAlarmClock: IconDefinition;
export const faHelicopterSymbol: IconDefinition;
export const faHouseChimneyCrack: IconDefinition;
export const faHouseDamage: IconDefinition;
export const faPersonMilitaryPointing: IconDefinition;
export const faDatabase: IconDefinition;
export const faNewspaper: IconDefinition;
export const faCloudRain: IconDefinition;
export const faMaximize: IconDefinition;
export const faExpandArrowsAlt: IconDefinition;
export const faLocationArrow: IconDefinition;
export const faCity: IconDefinition;
export const faXRay: IconDefinition;
export const faUmbrellaBeach: IconDefinition;
export const faArrowRightToBracket: IconDefinition;
export const faSignIn: IconDefinition;
export const faHeadset: IconDefinition;
export const faSplotch: IconDefinition;
export const faUpLong: IconDefinition;
export const faLongArrowAltUp: IconDefinition;
export const faHexagonNodes: IconDefinition;
export const faHospital: IconDefinition;
export const faHospitalAlt: IconDefinition;
export const faHospitalWide: IconDefinition;
export const faPersonHarassing: IconDefinition;
export const faMoneyBillTrendUp: IconDefinition;
export const faPenRuler: IconDefinition;
export const faPencilRuler: IconDefinition;
export const faRepeat: IconDefinition;
export const faBone: IconDefinition;
export const faFireFlameCurved: IconDefinition;
export const faFireAlt: IconDefinition;
export const faBusSimple: IconDefinition;
export const faBusAlt: IconDefinition;
export const faVenusMars: IconDefinition;
export const faBlender: IconDefinition;
export const faU: IconDefinition;
export const faShare: IconDefinition;
export const faMailForward: IconDefinition;
export const faPhoneFlip: IconDefinition;
export const faPhoneAlt: IconDefinition;
export const faToiletPortable: IconDefinition;
export const faPersonPregnant: IconDefinition;
export const faLessThan: IconDefinition;
export const faSuperscript: IconDefinition;
export const faCircleStop: IconDefinition;
export const faStopCircle: IconDefinition;
export const faArrowsUpDown: IconDefinition;
export const faArrowsV: IconDefinition;
export const faPooStorm: IconDefinition;
export const faPooBolt: IconDefinition;
export const faVideoSlash: IconDefinition;
export const faSquareXmark: IconDefinition;
export const faTimesSquare: IconDefinition;
export const faXmarkSquare: IconDefinition;
export const faHandHoldingDroplet: IconDefinition;
export const faHandHoldingWater: IconDefinition;
export const faWonSign: IconDefinition;
export const faKrw: IconDefinition;
export const faWon: IconDefinition;
export const faObjectUngroup: IconDefinition;
export const faComment: IconDefinition;
export const faHillAvalanche: IconDefinition;
export const faArrowsToEye: IconDefinition;
export const faSnowplow: IconDefinition;
export const faChartGantt: IconDefinition;
export const faVideo: IconDefinition;
export const faVideoCamera: IconDefinition;
export const faChessPawn: IconDefinition;
export const faSynagogue: IconDefinition;
export const faBuildingCircleCheck: IconDefinition;
export const faCalendarPlus: IconDefinition;
export const faWheelchairMove: IconDefinition;
export const faWheelchairAlt: IconDefinition;
export const faUserShield: IconDefinition;
export const faBold: IconDefinition;
export const faHeartPulse: IconDefinition;
export const faHeartbeat: IconDefinition;
export const faSquareRootVariable: IconDefinition;
export const faSquareRootAlt: IconDefinition;
export const faHandsBubbles: IconDefinition;
export const faHandsWash: IconDefinition;
export const faMarker: IconDefinition;
export const faClipboard: IconDefinition;
export const faPlaceOfWorship: IconDefinition;
export const faCannabis: IconDefinition;
export const faPeopleRoof: IconDefinition;
export const faDisease: IconDefinition;
export const faBookBible: IconDefinition;
export const faBible: IconDefinition;
export const faChessBoard: IconDefinition;
export const faMars: IconDefinition;
export const faLaptop: IconDefinition;
export const faUserXmark: IconDefinition;
export const faUserTimes: IconDefinition;
export const faFlagUsa: IconDefinition;
export const faHandMiddleFinger: IconDefinition;
export const faMortarPestle: IconDefinition;
export const faHeadSideCough: IconDefinition;
export const faPlaneLock: IconDefinition;
export const faBatteryThreeQuarters: IconDefinition;
export const faBattery4: IconDefinition;
export const faFrancSign: IconDefinition;
export const faFilterCircleDollar: IconDefinition;
export const faFunnelDollar: IconDefinition;
export const faCheese: IconDefinition;
export const faCircleH: IconDefinition;
export const faHospitalSymbol: IconDefinition;
export const faSchool: IconDefinition;
export const faDiceFive: IconDefinition;
export const faTornado: IconDefinition;
export const faJetFighter: IconDefinition;
export const faFighterJet: IconDefinition;
export const faThumbsDown: IconDefinition;
export const faBroom: IconDefinition;
export const faFileImport: IconDefinition;
export const faArrowRightToFile: IconDefinition;
export const faUtensils: IconDefinition;
export const faCutlery: IconDefinition;
export const faIdBadge: IconDefinition;
export const faSpider: IconDefinition;
export const faMobileRetro: IconDefinition;
export const faSignsPost: IconDefinition;
export const faMapSigns: IconDefinition;
export const faGroupArrowsRotate: IconDefinition;
export const faArrowsSplitUpAndLeft: IconDefinition;
export const faFillDrip: IconDefinition;
export const faShieldHeart: IconDefinition;
export const faPersonSkiingNordic: IconDefinition;
export const faSkiingNordic: IconDefinition;
export const faSquareCheck: IconDefinition;
export const faCheckSquare: IconDefinition;
export const faBath: IconDefinition;
export const faBathtub: IconDefinition;
export const faChessBishop: IconDefinition;
export const faPrescriptionBottleMedical: IconDefinition;
export const faPrescriptionBottleAlt: IconDefinition;
export const faDrawPolygon: IconDefinition;
export const faVectorPolygon: IconDefinition;
export const faICursor: IconDefinition;
export const faHeartCirclePlus: IconDefinition;
export const faShieldDog: IconDefinition;
export const faGreaterThanEqual: IconDefinition;
export const faEnvelopeOpen: IconDefinition;
export const faMound: IconDefinition;
export const faVoicemail: IconDefinition;
export const faVest: IconDefinition;
export const faAudioDescription: IconDefinition;
export const faW: IconDefinition;
export const faEyeDropper: IconDefinition;
export const faEyeDropperEmpty: IconDefinition;
export const faEyedropper: IconDefinition;
export const faCircleXmark: IconDefinition;
export const faTimesCircle: IconDefinition;
export const faXmarkCircle: IconDefinition;
export const faTrailer: IconDefinition;
export const faTurkishLiraSign: IconDefinition;
export const faTry: IconDefinition;
export const faTurkishLira: IconDefinition;
export const faVolcano: IconDefinition;
export const faWandSparkles: IconDefinition;
export const faMicrophone: IconDefinition;
export const faCrown: IconDefinition;
export const faTentArrowTurnLeft: IconDefinition;
export const faTruckFast: IconDefinition;
export const faShippingFast: IconDefinition;
export const faUserPen: IconDefinition;
export const faUserEdit: IconDefinition;
export const faUserClock: IconDefinition;
export const faShower: IconDefinition;
export const faSquareCaretUp: IconDefinition;
export const faCaretSquareUp: IconDefinition;
export const faMapLocation: IconDefinition;
export const faMapMarked: IconDefinition;
export const faPenFancy: IconDefinition;
export const faEuroSign: IconDefinition;
export const faEur: IconDefinition;
export const faEuro: IconDefinition;
export const faHouseCircleXmark: IconDefinition;
export const faLiraSign: IconDefinition;
export const faYenSign: IconDefinition;
export const faCny: IconDefinition;
export const faJpy: IconDefinition;
export const faRmb: IconDefinition;
export const faYen: IconDefinition;
export const faBoxOpen: IconDefinition;
export const faTruckField: IconDefinition;
export const faLocationPinLock: IconDefinition;
export const faPersonPraying: IconDefinition;
export const faPray: IconDefinition;
export const faClipboardList: IconDefinition;
export const faSackDollar: IconDefinition;
export const faMountainSun: IconDefinition;
export const faArrowUpWideShort: IconDefinition;
export const faSortAmountUp: IconDefinition;
export const faUsersLine: IconDefinition;
export const faStarOfDavid: IconDefinition;
export const faNotesMedical: IconDefinition;
export const faAustralSign: IconDefinition;
export const faClipboardUser: IconDefinition;
export const faFileImage: IconDefinition;
export const faSquareCaretRight: IconDefinition;
export const faCaretSquareRight: IconDefinition;
export const faVial: IconDefinition;
export const faHelicopter: IconDefinition;
export const faMitten: IconDefinition;
export const faGasPump: IconDefinition;
export const faEnvelopeCircleCheck: IconDefinition;
export const faPersonSkating: IconDefinition;
export const faSkating: IconDefinition;
export const faSun: IconDefinition;
export const faBaseball: IconDefinition;
export const faBaseballBall: IconDefinition;
export const faImage: IconDefinition;
export const faNotdef: IconDefinition;
export const faBasketball: IconDefinition;
export const faBasketballBall: IconDefinition;
export const faPencil: IconDefinition;
export const faPencilAlt: IconDefinition;
export const faPersonWalkingArrowLoopLeft: IconDefinition;
export const faDiceSix: IconDefinition;
export const faAnglesDown: IconDefinition;
export const faAngleDoubleDown: IconDefinition;
export const faSyringe: IconDefinition;
export const faWheatAwn: IconDefinition;
export const faWheatAlt: IconDefinition;
export const faPlaneUp: IconDefinition;
export const faAlignCenter: IconDefinition;
export const faHockeyPuck: IconDefinition;
export const faCircleArrowLeft: IconDefinition;
export const faArrowCircleLeft: IconDefinition;
export const faPlugCircleBolt: IconDefinition;
export const faRestroom: IconDefinition;
export const faAnchorLock: IconDefinition;
export const faTimeline: IconDefinition;
export const faLightbulb: IconDefinition;
export const faCircleArrowRight: IconDefinition;
export const faArrowCircleRight: IconDefinition;
export const faMarsAndVenus: IconDefinition;
export const faNetworkWired: IconDefinition;
export const faBuildingShield: IconDefinition;
export const faCode: IconDefinition;
export const faFeatherPointed: IconDefinition;
export const faFeatherAlt: IconDefinition;
export const faFileCircleQuestion: IconDefinition;
export const faSignature: IconDefinition;
export const faEarthAmericas: IconDefinition;
export const faEarth: IconDefinition;
export const faEarthAmerica: IconDefinition;
export const faGlobeAmericas: IconDefinition;
export const faCarrot: IconDefinition;
export const faTemperatureFull: IconDefinition;
export const faTemperature4: IconDefinition;
export const faThermometer4: IconDefinition;
export const faThermometerFull: IconDefinition;
export const faTableCellsRowLock: IconDefinition;
export const faBoltLightning: IconDefinition;
export const faCloudShowersWater: IconDefinition;
export const faArrowUpLong: IconDefinition;
export const faLongArrowUp: IconDefinition;
export const faAddressCard: IconDefinition;
export const faContactCard: IconDefinition;
export const faVcard: IconDefinition;
export const faAngleRight: IconDefinition;
export const faFaceMeh: IconDefinition;
export const faMeh: IconDefinition;
export const faArrowUpFromGroundWater: IconDefinition;
export const faMap: IconDefinition;
export const faUserPlus: IconDefinition;
export const faVenus: IconDefinition;
export const faDiagramSuccessor: IconDefinition;
export const faHeadSideCoughSlash: IconDefinition;
export const faDiagramProject: IconDefinition;
export const faProjectDiagram: IconDefinition;
export const faTerminal: IconDefinition;
export const faHouseFire: IconDefinition;
export const faMask: IconDefinition;
export const faHurricane: IconDefinition;
export const faEarthAfrica: IconDefinition;
export const faGlobeAfrica: IconDefinition;
export const faThumbtack: IconDefinition;
export const faThumbTack: IconDefinition;
export const faHandPointDown: IconDefinition;
export const faFaceMehBlank: IconDefinition;
export const faMehBlank: IconDefinition;
export const faTemperatureEmpty: IconDefinition;
export const faTemperature0: IconDefinition;
export const faThermometer0: IconDefinition;
export const faThermometerEmpty: IconDefinition;
export const faBorderNone: IconDefinition;
export const faHighlighter: IconDefinition;
export const faMoneyBillWave: IconDefinition;
export const faToiletPaperSlash: IconDefinition;
export const faFileShield: IconDefinition;
export const faTextHeight: IconDefinition;
export const faFaceGrinTongue: IconDefinition;
export const faGrinTongue: IconDefinition;
export const faFileSignature: IconDefinition;
export const faBuildingWheat: IconDefinition;
export const faPlugCircleMinus: IconDefinition;
export const faFutbol: IconDefinition;
export const faFutbolBall: IconDefinition;
export const faSoccerBall: IconDefinition;
export const faCirclePlus: IconDefinition;
export const faPlusCircle: IconDefinition;
export const faBrazilianRealSign: IconDefinition;
export const faStarAndCrescent: IconDefinition;
export const faFaceSurprise: IconDefinition;
export const faSurprise: IconDefinition;
export const faHospitalUser: IconDefinition;
export const faArrowDownUpLock: IconDefinition;
export const faFolder: IconDefinition;
export const faFolderBlank: IconDefinition;
export const faHollyBerry: IconDefinition;
export const faVenusDouble: IconDefinition;
export const faClipboardQuestion: IconDefinition;
export const faHotdog: IconDefinition;
export const faArrowUpFromBracket: IconDefinition;
export const faMicroscope: IconDefinition;
export const faCloud: IconDefinition;
export const faBaseballBatBall: IconDefinition;
export const faCarRear: IconDefinition;
export const faCarAlt: IconDefinition;
export const faThumbtackSlash: IconDefinition;
export const faThumbTackSlash: IconDefinition;
export const faPlusMinus: IconDefinition;
export const faHouseCircleCheck: IconDefinition;
export const faCalendarDay: IconDefinition;
export const faLibra: IconDefinition;
export const faCircle: IconDefinition;
export const faMobileVibrate: IconDefinition;
export const faFaceGrinSquint: IconDefinition;
export const faGrinSquint: IconDefinition;
export const faUsersBetweenLines: IconDefinition;
export const faHouseMedicalCircleXmark: IconDefinition;
export const faTableList: IconDefinition;
export const faThList: IconDefinition;
export const faFlaskVial: IconDefinition;
export const faCircleExclamation: IconDefinition;
export const faExclamationCircle: IconDefinition;
export const faTaxi: IconDefinition;
export const faCab: IconDefinition;
export const faTextSlash: IconDefinition;
export const faRemoveFormat: IconDefinition;
export const faPeoplePulling: IconDefinition;
export const faBackward: IconDefinition;
export const faCarBurst: IconDefinition;
export const faCarCrash: IconDefinition;
export const faLink: IconDefinition;
export const faChain: IconDefinition;
export const faBackwardStep: IconDefinition;
export const faStepBackward: IconDefinition;
export const faX: IconDefinition;
export const faCircleUser: IconDefinition;
export const faUserCircle: IconDefinition;
export const faRectangleList: IconDefinition;
export const faListAlt: IconDefinition;
export const faHand: IconDefinition;
export const faHandPaper: IconDefinition;
export const faCancer: IconDefinition;
export const faVanShuttle: IconDefinition;
export const faShuttleVan: IconDefinition;
export const faStairs: IconDefinition;
export const faHorseHead: IconDefinition;
export const faVault: IconDefinition;
export const faClosedCaptioningSlash: IconDefinition;
export const faDrumSteelpan: IconDefinition;
export const faThumbsUp: IconDefinition;
export const faStamp: IconDefinition;
export const faMenorah: IconDefinition;
export const faChildren: IconDefinition;
export const faChartLine: IconDefinition;
export const faLineChart: IconDefinition;
export const faSquareEnvelope: IconDefinition;
export const faEnvelopeSquare: IconDefinition;
export const faBanSmoking: IconDefinition;
export const faSmokingBan: IconDefinition;
export const faTruckFront: IconDefinition;
export const faBuilding: IconDefinition;
export const faBullseye: IconDefinition;
export const faArrowLeftLong: IconDefinition;
export const faLongArrowLeft: IconDefinition;
export const faChessRook: IconDefinition;
export const faBlenderPhone: IconDefinition;
export const faArrowTurnUp: IconDefinition;
export const faLevelUp: IconDefinition;
export const faBicycle: IconDefinition;
export const faCircleArrowDown: IconDefinition;
export const faArrowCircleDown: IconDefinition;
export const faGear: IconDefinition;
export const faCog: IconDefinition;
export const faMarsAndVenusBurst: IconDefinition;
export const faOtter: IconDefinition;
export const faCircleChevronLeft: IconDefinition;
export const faChevronCircleLeft: IconDefinition;
export const faCircleQuestion: IconDefinition;
export const faQuestionCircle: IconDefinition;
export const faWalkieTalkie: IconDefinition;
export const faUserGroup: IconDefinition;
export const faUserFriends: IconDefinition;
export const faHouseChimney: IconDefinition;
export const faHomeLg: IconDefinition;
export const faRightFromBracket: IconDefinition;
export const faSignOutAlt: IconDefinition;
export const faFile: IconDefinition;
export const faPlaneSlash: IconDefinition;
export const faCloudShowersHeavy: IconDefinition;
export const faPersonFalling: IconDefinition;
export const faTurnDown: IconDefinition;
export const faLevelDownAlt: IconDefinition;
export const faUpRightAndDownLeftFromCenter: IconDefinition;
export const faExpandAlt: IconDefinition;
export const faUserTag: IconDefinition;
export const faHandSparkles: IconDefinition;
export const faArrowsToDot: IconDefinition;
export const faFaceSadCry: IconDefinition;
export const faSadCry: IconDefinition;
export const faDongSign: IconDefinition;
export const faPeopleLine: IconDefinition;
export const faSquareRss: IconDefinition;
export const faRssSquare: IconDefinition;
export const faCalendarMinus: IconDefinition;
export const faChartDiagram: IconDefinition;
export const faFaceTired: IconDefinition;
export const faTired: IconDefinition;
export const faHandPointRight: IconDefinition;
export const faArrowUp: IconDefinition;
export const faCubesStacked: IconDefinition;
export const faChildCombatant: IconDefinition;
export const faChildRifle: IconDefinition;
export const faVestPatches: IconDefinition;
export const faMartiniGlassEmpty: IconDefinition;
export const faGlassMartini: IconDefinition;
export const faMagnet: IconDefinition;
export const faRoadBarrier: IconDefinition;
export const faCompassDrafting: IconDefinition;
export const faDraftingCompass: IconDefinition;
export const faSquarePersonConfined: IconDefinition;
export const faPlateWheat: IconDefinition;
export const faSignHanging: IconDefinition;
export const faSign: IconDefinition;
export const faCarBattery: IconDefinition;
export const faBatteryCar: IconDefinition;
export const faShirt: IconDefinition;
export const faTShirt: IconDefinition;
export const faTshirt: IconDefinition;
export const faParagraph: IconDefinition;
export const faEnvelopesBulk: IconDefinition;
export const faMailBulk: IconDefinition;
export const faGuitar: IconDefinition;
export const faSuitcase: IconDefinition;
export const faCircleUp: IconDefinition;
export const faArrowAltCircleUp: IconDefinition;
export const faF: IconDefinition;
export const faXmarksLines: IconDefinition;
export const faEarthOceania: IconDefinition;
export const faGlobeOceania: IconDefinition;
export const faCommentSlash: IconDefinition;
export const faPlay: IconDefinition;
export const faVialCircleCheck: IconDefinition;
export const faBridgeCircleCheck: IconDefinition;
export const faCediSign: IconDefinition;
export const faPuzzlePiece: IconDefinition;
export const faHelmetUn: IconDefinition;
export const faGlassWater: IconDefinition;
export const faHeartCircleBolt: IconDefinition;
export const faPumpSoap: IconDefinition;
export const faHandScissors: IconDefinition;
export const faDolly: IconDefinition;
export const faDollyBox: IconDefinition;
export const faPaperclip: IconDefinition;
export const faDemocrat: IconDefinition;
export const faSquareArrowUpRight: IconDefinition;
export const faExternalLinkSquare: IconDefinition;
export const faFerry: IconDefinition;
export const faMosquito: IconDefinition;
export const faBuildingCircleArrowRight: IconDefinition;
export const faLeftRight: IconDefinition;
export const faArrowsAltH: IconDefinition;
export const faVirus: IconDefinition;
export const faGem: IconDefinition;
export const faToilet: IconDefinition;
export const faSingleQuoteLeft: IconDefinition;
export const faMoneyBills: IconDefinition;
export const faTabletButton: IconDefinition;
export const faRectangleXmark: IconDefinition;
export const faRectangleTimes: IconDefinition;
export const faTimesRectangle: IconDefinition;
export const faWindowClose: IconDefinition;
export const faWrench: IconDefinition;
export const faTrashCan: IconDefinition;
export const faTrashAlt: IconDefinition;
export const faTableCells: IconDefinition;
export const faTh: IconDefinition;
export const faRibbon: IconDefinition;
export const faLandmarkFlag: IconDefinition;
export const faUpDownLeftRight: IconDefinition;
export const faArrowsAlt: IconDefinition;
export const faCarSide: IconDefinition;
export const faTrashArrowUp: IconDefinition;
export const faTrashRestore: IconDefinition;
export const faLifeRing: IconDefinition;
export const faCopyright: IconDefinition;
export const faFilePrescription: IconDefinition;
export const faEraser: IconDefinition;
export const faHourglassStart: IconDefinition;
export const faHourglass1: IconDefinition;
export const faCircleLeft: IconDefinition;
export const faArrowAltCircleLeft: IconDefinition;
export const faCruzeiroSign: IconDefinition;
export const faSmoking: IconDefinition;
export const faSquarePollVertical: IconDefinition;
export const faPoll: IconDefinition;
export const faPersonCircleMinus: IconDefinition;
export const faBiohazard: IconDefinition;
export const faBellConcierge: IconDefinition;
export const faConciergeBell: IconDefinition;
export const faRulerHorizontal: IconDefinition;
export const faHorse: IconDefinition;
export const faCalendar: IconDefinition;
export const faHandsHoldingChild: IconDefinition;
export const faItalic: IconDefinition;
export const faKhanda: IconDefinition;
export const faFaceFrownOpen: IconDefinition;
export const faFrownOpen: IconDefinition;
export const faCheck: IconDefinition;
export const faFingerprint: IconDefinition;
export const faChargingStation: IconDefinition;
export const faUserLock: IconDefinition;
export const faMobileScreenButton: IconDefinition;
export const faMobileAlt: IconDefinition;
export const faAnchorCircleCheck: IconDefinition;
export const faPersonWalkingWithCane: IconDefinition;
export const faBlind: IconDefinition;
export const faFileWaveform: IconDefinition;
export const faFileMedicalAlt: IconDefinition;
export const faHouseCrack: IconDefinition;
export const faHatWizard: IconDefinition;
export const faUserDoctor: IconDefinition;
export const faUserMd: IconDefinition;
export const faChartBar: IconDefinition;
export const faBarChart: IconDefinition;
export const faSprayCanSparkles: IconDefinition;
export const faAirFreshener: IconDefinition;
export const faBahtSign: IconDefinition;
export const faTemperatureArrowUp: IconDefinition;
export const faTemperatureUp: IconDefinition;
export const faWebAwesome: IconDefinition;
export const faNonBinary: IconDefinition;
export const faN: IconDefinition;
export const faArrowsUpDownLeftRight: IconDefinition;
export const faArrows: IconDefinition;
export const faHouse: IconDefinition;
export const faHome: IconDefinition;
export const faHomeAlt: IconDefinition;
export const faHomeLgAlt: IconDefinition;
export const faSpinner: IconDefinition;
export const faGavel: IconDefinition;
export const faLegal: IconDefinition;
export const faTicketSimple: IconDefinition;
export const faTicketAlt: IconDefinition;
export const faDove: IconDefinition;
export const faTarpDroplet: IconDefinition;
export const faTreeCity: IconDefinition;
export const faTurnUp: IconDefinition;
export const faLevelUpAlt: IconDefinition;
export const faTemperatureQuarter: IconDefinition;
export const faTemperature1: IconDefinition;
export const faThermometer1: IconDefinition;
export const faThermometerQuarter: IconDefinition;
export const faSliders: IconDefinition;
export const faSlidersH: IconDefinition;
export const faMosque: IconDefinition;
export const faH: IconDefinition;
export const faInfo: IconDefinition;
export const faPersonWalking: IconDefinition;
export const faWalking: IconDefinition;
export const faArrowTurnDown: IconDefinition;
export const faLevelDown: IconDefinition;
export const faRoad: IconDefinition;
export const faSpiral: IconDefinition;
export const faFaceFrown: IconDefinition;
export const faFrown: IconDefinition;
export const faWineGlassEmpty: IconDefinition;
export const faWineGlassAlt: IconDefinition;
export const faClapperboard: IconDefinition;
export const faForwardStep: IconDefinition;
export const faStepForward: IconDefinition;
export const faSquareUpRight: IconDefinition;
export const faExternalLinkSquareAlt: IconDefinition;
export const faBookJournalWhills: IconDefinition;
export const faJournalWhills: IconDefinition;
export const faChampagneGlasses: IconDefinition;
export const faGlassCheers: IconDefinition;
export const faDumpster: IconDefinition;
export const faHeartCircleXmark: IconDefinition;
export const faComputer: IconDefinition;
export const faWandMagic: IconDefinition;
export const faMagic: IconDefinition;
export const faBrain: IconDefinition;
export const faBriefcaseMedical: IconDefinition;
export const faHouseMedicalCircleExclamation: IconDefinition;
export const faCodeCommit: IconDefinition;
export const faPersonBreastfeeding: IconDefinition;
export const faPersonRays: IconDefinition;
export const faManatSign: IconDefinition;
export const faSort: IconDefinition;
export const faUnsorted: IconDefinition;
export const faCircleRadiation: IconDefinition;
export const faRadiationAlt: IconDefinition;
export const faLaptopCode: IconDefinition;
export const faSink: IconDefinition;
export const faArrowUpFromWaterPump: IconDefinition;
export const faMicrophoneLinesSlash: IconDefinition;
export const faMicrophoneAltSlash: IconDefinition;
export const faServer: IconDefinition;
export const faUser: IconDefinition;
export const faUserAlt: IconDefinition;
export const faUserLarge: IconDefinition;
export const faSnowflake: IconDefinition;
export const faTaurus: IconDefinition;
export const faSkullCrossbones: IconDefinition;
export const faPesoSign: IconDefinition;
export const faWineGlass: IconDefinition;
export const faTemperatureHalf: IconDefinition;
export const faTemperature2: IconDefinition;
export const faThermometer2: IconDefinition;
export const faThermometerHalf: IconDefinition;
export const faTicket: IconDefinition;
export const faWheatAwnCircleExclamation: IconDefinition;
export const faArrowsTurnRight: IconDefinition;
export const faCandyCane: IconDefinition;
export const faWheelchair: IconDefinition;
export const faSpellCheck: IconDefinition;
export const faVolumeOff: IconDefinition;
export const faLungs: IconDefinition;
export const faBookmark: IconDefinition;
export const faBarcode: IconDefinition;
export const faListOl: IconDefinition;
export const faList12: IconDefinition;
export const faListNumeric: IconDefinition;
export const faFileCircleXmark: IconDefinition;
export const faCube: IconDefinition;
export const faTape: IconDefinition;
export const faBomb: IconDefinition;
export const faScaleUnbalanced: IconDefinition;
export const faBalanceScaleLeft: IconDefinition;
export const faSquareCaretLeft: IconDefinition;
export const faCaretSquareLeft: IconDefinition;
export const faRuler: IconDefinition;
export const faI: IconDefinition;
export const faVolumeXmark: IconDefinition;
export const faVolumeMute: IconDefinition;
export const faVolumeTimes: IconDefinition;
export const faArchway: IconDefinition;
export const faPersonDigging: IconDefinition;
export const faDigging: IconDefinition;
export const faGaugeHigh: IconDefinition;
export const faTachometerAlt: IconDefinition;
export const faTachometerAltFast: IconDefinition;
export const faGenderless: IconDefinition;
export const faCloudSun: IconDefinition;
export const faArrowRight: IconDefinition;
export const faHandshake: IconDefinition;
export const faHandshakeAlt: IconDefinition;
export const faHandshakeSimple: IconDefinition;
export const faPersonSkiing: IconDefinition;
export const faSkiing: IconDefinition;
export const faBridgeWater: IconDefinition;
export const faBuildingNgo: IconDefinition;
export const faIgloo: IconDefinition;
export const faCircleDollarToSlot: IconDefinition;
export const faDonate: IconDefinition;
export const faY: IconDefinition;
export const faFaceSmileWink: IconDefinition;
export const faSmileWink: IconDefinition;
export const faDiceFour: IconDefinition;
export const faFaceGrinSquintTears: IconDefinition;
export const faGrinSquintTears: IconDefinition;
export const faFileAudio: IconDefinition;
export const faArrowsDownToLine: IconDefinition;
export const faG: IconDefinition;
export const faVihara: IconDefinition;
export const faFlagCheckered: IconDefinition;
export const faGaugeSimple: IconDefinition;
export const faGaugeSimpleMed: IconDefinition;
export const faTachometerAverage: IconDefinition;
export const faRightLeft: IconDefinition;
export const faExchangeAlt: IconDefinition;
export const faPills: IconDefinition;
export const faExplosion: IconDefinition;
export const faArrowsDownToPeople: IconDefinition;
export const faUsersViewfinder: IconDefinition;
export const faCarOn: IconDefinition;
export const faSleigh: IconDefinition;
export const faDumbbell: IconDefinition;
export const faBabyCarriage: IconDefinition;
export const faCarriageBaby: IconDefinition;
export const faKiwiBird: IconDefinition;
export const faCalendarXmark: IconDefinition;
export const faCalendarTimes: IconDefinition;
export const faCircleDown: IconDefinition;
export const faArrowAltCircleDown: IconDefinition;
export const faFileMedical: IconDefinition;
export const faXmark: IconDefinition;
export const faClose: IconDefinition;
export const faMultiply: IconDefinition;
export const faRemove: IconDefinition;
export const faTimes: IconDefinition;
export const faShapes: IconDefinition;
export const faTriangleCircleSquare: IconDefinition;
export const faDiceOne: IconDefinition;
export const faLockOpen: IconDefinition;
export const faPepperHot: IconDefinition;
export const faDropletSlash: IconDefinition;
export const faTintSlash: IconDefinition;
export const faDroplet: IconDefinition;
export const faTint: IconDefinition;
export const faFileLines: IconDefinition;
export const faFileAlt: IconDefinition;
export const faFileText: IconDefinition;
export const faCommentsDollar: IconDefinition;
export const faMagnifyingGlassLocation: IconDefinition;
export const faSearchLocation: IconDefinition;
export const faFileInvoice: IconDefinition;
export const faPentagon: IconDefinition;
export const faRepublican: IconDefinition;
export const faShop: IconDefinition;
export const faStoreAlt: IconDefinition;
export const faFilm: IconDefinition;
export const faFilmAlt: IconDefinition;
export const faFilmSimple: IconDefinition;
export const faBuildingCircleXmark: IconDefinition;
export const faComments: IconDefinition;
export const faTags: IconDefinition;
export const faGun: IconDefinition;
export const faCircleCheck: IconDefinition;
export const faCheckCircle: IconDefinition;
export const faScorpio: IconDefinition;
export const faIdCardClip: IconDefinition;
export const faIdCardAlt: IconDefinition;
export const faMoon: IconDefinition;
export const faOilWell: IconDefinition;
export const faTachographDigital: IconDefinition;
export const faDigitalTachograph: IconDefinition;
export const faTablet: IconDefinition;
export const faTabletAndroid: IconDefinition;
export const faRubleSign: IconDefinition;
export const faRouble: IconDefinition;
export const faRub: IconDefinition;
export const faRuble: IconDefinition;
export const faClosedCaptioning: IconDefinition;
export const faPen: IconDefinition;
export const faPlane: IconDefinition;
export const faImages: IconDefinition;
export const faMobileScreen: IconDefinition;
export const faMobileAndroidAlt: IconDefinition;
export const faGuaraniSign: IconDefinition;
export const faBagShopping: IconDefinition;
export const faShoppingBag: IconDefinition;
export const faCircleRight: IconDefinition;
export const faArrowAltCircleRight: IconDefinition;
export const faPhoneVolume: IconDefinition;
export const faVolumeControlPhone: IconDefinition;
export const faCubes: IconDefinition;
export const faPhone: IconDefinition;
export const faToriiGate: IconDefinition;
export const faBacon: IconDefinition;
export const faPersonFallingBurst: IconDefinition;
export const faQuoteRight: IconDefinition;
export const faQuoteRightAlt: IconDefinition;
export const faHouseMedicalFlag: IconDefinition;
export const faPrescription: IconDefinition;
export const faDiceThree: IconDefinition;
export const faBuildingLock: IconDefinition;
export const faIdCard: IconDefinition;
export const faDriversLicense: IconDefinition;
export const faCirclePlay: IconDefinition;
export const faPlayCircle: IconDefinition;
export const faFaceLaughBeam: IconDefinition;
export const faLaughBeam: IconDefinition;
export const faLeaf: IconDefinition;
export const faHouseChimneyUser: IconDefinition;
export const faRotateRight: IconDefinition;
export const faRedoAlt: IconDefinition;
export const faRotateForward: IconDefinition;
export const faTooth: IconDefinition;
export const faHouseChimneyWindow: IconDefinition;
export const faMotorcycle: IconDefinition;
export const faBackwardFast: IconDefinition;
export const faFastBackward: IconDefinition;
export const faAddressBook: IconDefinition;
export const faContactBook: IconDefinition;
export const faSailboat: IconDefinition;
export const faBookBookmark: IconDefinition;
export const faMagnifyingGlassArrowRight: IconDefinition;
export const faMicrophoneLines: IconDefinition;
export const faMicrophoneAlt: IconDefinition;
export const faReplyAll: IconDefinition;
export const faMailReplyAll: IconDefinition;
export const faUniversalAccess: IconDefinition;
export const faToiletPaper: IconDefinition;
export const faToiletPaperAlt: IconDefinition;
export const faToiletPaperBlank: IconDefinition;
export const faVrCardboard: IconDefinition;
export const faPizzaSlice: IconDefinition;
export const faSprayCan: IconDefinition;
export const faVolumeLow: IconDefinition;
export const faVolumeDown: IconDefinition;
export const faCross: IconDefinition;
export const faPerson: IconDefinition;
export const faMale: IconDefinition;
export const faHourglass: IconDefinition;
export const faHourglassEmpty: IconDefinition;
export const faFish: IconDefinition;
export const faDrumstickBite: IconDefinition;
export const faChartSimple: IconDefinition;
export const faAtom: IconDefinition;
export const faP: IconDefinition;
export const faJetFighterUp: IconDefinition;
export const faPlugCircleXmark: IconDefinition;
export const faSheetPlastic: IconDefinition;
export const faV: IconDefinition;
export const faList: IconDefinition;
export const faListSquares: IconDefinition;
export const faPisces: IconDefinition;
export const faSolarPanel: IconDefinition;
export const faLandMineOn: IconDefinition;
export const faHeadphones: IconDefinition;
export const faHeadphonesAlt: IconDefinition;
export const faHeadphonesSimple: IconDefinition;
export const faBus: IconDefinition;
export const faFilePowerpoint: IconDefinition;
export const faQuoteLeft: IconDefinition;
export const faQuoteLeftAlt: IconDefinition;
export const faChevronDown: IconDefinition;
export const faEarthAsia: IconDefinition;
export const faGlobeAsia: IconDefinition;
export const faCentSign: IconDefinition;
export const faShieldCat: IconDefinition;
export const faSchoolCircleCheck: IconDefinition;
export const faMartiniGlass: IconDefinition;
export const faGlassMartiniAlt: IconDefinition;
export const faPlug: IconDefinition;
export const faPanorama: IconDefinition;
export const faClockRotateLeft: IconDefinition;
export const faHistory: IconDefinition;
export const faJarWheat: IconDefinition;
export const faCloudArrowDown: IconDefinition;
export const faCloudDownload: IconDefinition;
export const faCloudDownloadAlt: IconDefinition;
export const faTruckRampBox: IconDefinition;
export const faTruckLoading: IconDefinition;
export const faAngleDown: IconDefinition;
export const faPlugCircleCheck: IconDefinition;
export const faWindowMaximize: IconDefinition;
export const faHandsHoldingCircle: IconDefinition;
export const faLocationPin: IconDefinition;
export const faMapMarker: IconDefinition;
export const faBowlingBall: IconDefinition;
export const faCartFlatbed: IconDefinition;
export const faDollyFlatbed: IconDefinition;
export const faHouseUser: IconDefinition;
export const faHomeUser: IconDefinition;
export const faGhost: IconDefinition;
export const faCommentNodes: IconDefinition;
export const faPersonArrowDownToLine: IconDefinition;
export const faPlugCirclePlus: IconDefinition;
export const faPersonSwimming: IconDefinition;
export const faSwimmer: IconDefinition;
export const faCommentDots: IconDefinition;
export const faCommenting: IconDefinition;
export const faChartPie: IconDefinition;
export const faPieChart: IconDefinition;
export const faFrog: IconDefinition;
export const faWineBottle: IconDefinition;
export const faInbox: IconDefinition;
export const faSquareH: IconDefinition;
export const faHSquare: IconDefinition;
export const faHouseMedical: IconDefinition;
export const faCircleChevronRight: IconDefinition;
export const faChevronCircleRight: IconDefinition;
export const faFileCsv: IconDefinition;
export const faHatCowboy: IconDefinition;
export const faFaceGrinTongueWink: IconDefinition;
export const faGrinTongueWink: IconDefinition;
export const faL: IconDefinition;
export const faArrowDownShortWide: IconDefinition;
export const faSortAmountDesc: IconDefinition;
export const faSortAmountDownAlt: IconDefinition;
export const faHourglassHalf: IconDefinition;
export const faHourglass2: IconDefinition;
export const faSpoon: IconDefinition;
export const faUtensilSpoon: IconDefinition;
export const faCreditCard: IconDefinition;
export const faCreditCardAlt: IconDefinition;
export const faFileInvoiceDollar: IconDefinition;
export const faSpaghettiMonsterFlying: IconDefinition;
export const faPastafarianism: IconDefinition;
export const faMartiniGlassCitrus: IconDefinition;
export const faCocktail: IconDefinition;
export const faBullhorn: IconDefinition;
export const faBoxTissue: IconDefinition;
export const faMattressPillow: IconDefinition;
export const faChevronLeft: IconDefinition;
export const faCloudMoonRain: IconDefinition;
export const faArrowDown19: IconDefinition;
export const faSortNumericAsc: IconDefinition;
export const faSortNumericDown: IconDefinition;
export const faHandSpock: IconDefinition;
export const faWandMagicSparkles: IconDefinition;
export const faMagicWandSparkles: IconDefinition;
export const faCommentMedical: IconDefinition;
export const faBellSlash: IconDefinition;
export const faHandshakeSlash: IconDefinition;
export const faHandshakeAltSlash: IconDefinition;
export const faHandshakeSimpleSlash: IconDefinition;
export const faBottleWater: IconDefinition;
export const faDiceD20: IconDefinition;
export const faArrowDownZA: IconDefinition;
export const faSortAlphaDesc: IconDefinition;
export const faSortAlphaDownAlt: IconDefinition;
export const faBrush: IconDefinition;
export const faPersonWalkingDashedLineArrowRight: IconDefinition;
export const faArrowUpShortWide: IconDefinition;
export const faSortAmountUpAlt: IconDefinition;
export const faGripVertical: IconDefinition;
export const faGridVertical: IconDefinition;
export const faCarTunnel: IconDefinition;
export const faChartColumn: IconDefinition;
export const faCapricorn: IconDefinition;
export const faTruckArrowRight: IconDefinition;
export const faTv: IconDefinition;
export const faTelevision: IconDefinition;
export const faTvAlt: IconDefinition;
export const faSection: IconDefinition;
export const faPeace: IconDefinition;
export const faStar: IconDefinition;
export const faFlag: IconDefinition;
export const faTriangleExclamation: IconDefinition;
export const faExclamationTriangle: IconDefinition;
export const faWarning: IconDefinition;
export const faSchoolCircleExclamation: IconDefinition;
export const faGraduationCap: IconDefinition;
export const faMortarBoard: IconDefinition;
export const faStore: IconDefinition;
export const faUserAstronaut: IconDefinition;
export const faBuildingFlag: IconDefinition;
export const faMugSaucer: IconDefinition;
export const faCoffee: IconDefinition;
export const faLemon: IconDefinition;
export const faCaravan: IconDefinition;
export const faQ: IconDefinition;
export const faLock: IconDefinition;
export const faPaintRoller: IconDefinition;
export const faVolumeHigh: IconDefinition;
export const faVolumeUp: IconDefinition;
export const faFolderPlus: IconDefinition;
export const faMercury: IconDefinition;
export const faAnchor: IconDefinition;
export const faSquareParking: IconDefinition;
export const faParking: IconDefinition;
export const faHanukiah: IconDefinition;
export const faRotateLeft: IconDefinition;
export const faRotateBack: IconDefinition;
export const faRotateBackward: IconDefinition;
export const faUndoAlt: IconDefinition;
export const faHeading: IconDefinition;
export const faHeader: IconDefinition;
export const faCrosshairs: IconDefinition;
export const faCircleNodes: IconDefinition;
export const faWindowRestore: IconDefinition;
export const faR: IconDefinition;
export const faFilterCircleXmark: IconDefinition;
export const faGopuram: IconDefinition;
export const faHeartCircleMinus: IconDefinition;
export const faStarOfLife: IconDefinition;
export const faBusinessTime: IconDefinition;
export const faBriefcaseClock: IconDefinition;
export const faFireExtinguisher: IconDefinition;
export const faArrowDownLong: IconDefinition;
export const faLongArrowDown: IconDefinition;
export const faUserMinus: IconDefinition;
export const faMoneyCheck: IconDefinition;
export const faHouseLaptop: IconDefinition;
export const faLaptopHouse: IconDefinition;
export const faDownload: IconDefinition;
export const faSagittarius: IconDefinition;
export const faCouch: IconDefinition;
export const faRoadLock: IconDefinition;
export const faScissors: IconDefinition;
export const faCut: IconDefinition;
export const faBug: IconDefinition;
export const faArrowRightFromBracket: IconDefinition;
export const faSignOut: IconDefinition;
export const faHandHoldingHand: IconDefinition;
export const faStroopwafel: IconDefinition;
export const faChild: IconDefinition;
export const faIceCream: IconDefinition;
export const faComputerMouse: IconDefinition;
export const faMouse: IconDefinition;
export const faFaucet: IconDefinition;
export const faAward: IconDefinition;
export const faPersonDrowning: IconDefinition;
export const faCameraRotate: IconDefinition;
export const faFaceGrinHearts: IconDefinition;
export const faGrinHearts: IconDefinition;
export const faFileFragment: IconDefinition;
export const faPersonMilitaryRifle: IconDefinition;
export const faToggleOn: IconDefinition;
export const faLungsVirus: IconDefinition;
export const faTableTennisPaddleBall: IconDefinition;
export const faPingPongPaddleBall: IconDefinition;
export const faTableTennis: IconDefinition;
export const faBoxesPacking: IconDefinition;
export const faPersonChalkboard: IconDefinition;
export const faDiceTwo: IconDefinition;
export const faArrowRightArrowLeft: IconDefinition;
export const faExchange: IconDefinition;
export const faFootball: IconDefinition;
export const faFootballBall: IconDefinition;
export const faTruckMonster: IconDefinition;
export const faAsterisk: IconDefinition;
export const faBatteryFull: IconDefinition;
export const faBattery: IconDefinition;
export const faBattery5: IconDefinition;
export const faChildDress: IconDefinition;
export const faFaceKissBeam: IconDefinition;
export const faKissBeam: IconDefinition;
export const faTrashCanArrowUp: IconDefinition;
export const faTrashRestoreAlt: IconDefinition;
export const faFont: IconDefinition;
export const faBoreHole: IconDefinition;
export const faVirusCovid: IconDefinition;
export const faFilePdf: IconDefinition;
export const faLanguage: IconDefinition;
export const faShieldHalved: IconDefinition;
export const faShieldAlt: IconDefinition;
export const faCaretUp: IconDefinition;
export const faFilePen: IconDefinition;
export const faFileEdit: IconDefinition;
export const faPersonBiking: IconDefinition;
export const faBiking: IconDefinition;
export const faBookOpenReader: IconDefinition;
export const faBookReader: IconDefinition;
export const faGlassWaterDroplet: IconDefinition;
export const faTowerBroadcast: IconDefinition;
export const faBroadcastTower: IconDefinition;
export const faMinimize: IconDefinition;
export const faCompressArrowsAlt: IconDefinition;
export const faArrowRightToCity: IconDefinition;
export const faLaptopMedical: IconDefinition;
export const faBreadSlice: IconDefinition;
export const faGlobe: IconDefinition;
export const faFolderMinus: IconDefinition;
export const faMaskFace: IconDefinition;
export const faBong: IconDefinition;
export const faRoadBridge: IconDefinition;
export const faArrowUp91: IconDefinition;
export const faSortNumericUpAlt: IconDefinition;
export const faMountainCity: IconDefinition;
export const faArrowDown91: IconDefinition;
export const faSortNumericDesc: IconDefinition;
export const faSortNumericDownAlt: IconDefinition;
export const faFaceGrinWide: IconDefinition;
export const faGrinAlt: IconDefinition;
export const faPoop: IconDefinition;
export const faDharmachakra: IconDefinition;
export const faBatteryQuarter: IconDefinition;
export const faBattery2: IconDefinition;
export const faAnkh: IconDefinition;
export const faDiamond: IconDefinition;
export const faSubscript: IconDefinition;
export const faRupeeSign: IconDefinition;
export const faRupee: IconDefinition;
export const faPersonRifle: IconDefinition;
export const faD: IconDefinition;
export const faSquareNfi: IconDefinition;
export const faTeeth: IconDefinition;
export const faMagnifyingGlassDollar: IconDefinition;
export const faSearchDollar: IconDefinition;
export const faDumpsterFire: IconDefinition;
export const faUpload: IconDefinition;
export const faUserSlash: IconDefinition;
export const faUserAltSlash: IconDefinition;
export const faUserLargeSlash: IconDefinition;
export const faArrowLeft: IconDefinition;
export const faVialVirus: IconDefinition;
export const faCheckDouble: IconDefinition;
export const faPaw: IconDefinition;
export const faHelmetSafety: IconDefinition;
export const faHardHat: IconDefinition;
export const faHatHard: IconDefinition;
export const faE: IconDefinition;
export const faFaceLaughSquint: IconDefinition;
export const faLaughSquint: IconDefinition;
export const faDownLeftAndUpRightToCenter: IconDefinition;
export const faCompressAlt: IconDefinition;
export const faGifts: IconDefinition;
export const faBed: IconDefinition;
export const faMoneyBillTransfer: IconDefinition;
export const faPersonRunning: IconDefinition;
export const faRunning: IconDefinition;
export const faCircleChevronDown: IconDefinition;
export const faChevronCircleDown: IconDefinition;
export const faUserNurse: IconDefinition;
export const faFaceKissWinkHeart: IconDefinition;
export const faKissWinkHeart: IconDefinition;
export const faFill: IconDefinition;
export const faMoneyBill1Wave: IconDefinition;
export const faMoneyBillWaveAlt: IconDefinition;
export const faLandmark: IconDefinition;
export const faMusic: IconDefinition;
export const faBookMedical: IconDefinition;
export const faShuffle: IconDefinition;
export const faRandom: IconDefinition;
export const faUnderline: IconDefinition;
export const faBuildingUser: IconDefinition;
export const faRobot: IconDefinition;
export const faPlus: IconDefinition;
export const faAdd: IconDefinition;
export const faCopy: IconDefinition;
export const faChessKing: IconDefinition;
export const faHouseFloodWater: IconDefinition;
export const faBitcoinSign: IconDefinition;
export const faBox: IconDefinition;
export const faSquarePlus: IconDefinition;
export const faPlusSquare: IconDefinition;
export const faArrowsLeftRight: IconDefinition;
export const faArrowsH: IconDefinition;
export const faFan: IconDefinition;
export const faCrow: IconDefinition;
export const faFileCircleCheck: IconDefinition;
export const faLinkSlash: IconDefinition;
export const faChainBroken: IconDefinition;
export const faChainSlash: IconDefinition;
export const faUnlink: IconDefinition;
export const faArrowRotateRight: IconDefinition;
export const faArrowRightRotate: IconDefinition;
export const faArrowRotateForward: IconDefinition;
export const faRedo: IconDefinition;
export const faPenClip: IconDefinition;
export const faPenAlt: IconDefinition;
export const faDoorClosed: IconDefinition;
export const faArrowDownWideShort: IconDefinition;
export const faSortAmountAsc: IconDefinition;
export const faSortAmountDown: IconDefinition;
export const faCaretDown: IconDefinition;
export const faK: IconDefinition;
export const faCheckToSlot: IconDefinition;
export const faVoteYea: IconDefinition;
export const faFishFins: IconDefinition;
export const faCompress: IconDefinition;
export const faArrowUpAZ: IconDefinition;
export const faSortAlphaUp: IconDefinition;
export const faUserGraduate: IconDefinition;
export const faFileCode: IconDefinition;
export const faSoap: IconDefinition;
export const faRecycle: IconDefinition;
export const faFaceGrinWink: IconDefinition;
export const faGrinWink: IconDefinition;
export const faWaterLadder: IconDefinition;
export const faLadderWater: IconDefinition;
export const faSwimmingPool: IconDefinition;
export const faGemini: IconDefinition;
export const faTowerCell: IconDefinition;
export const faColonSign: IconDefinition;
export const faLaptopFile: IconDefinition;
export const faBahai: IconDefinition;
export const faHaykal: IconDefinition;
export const faMoneyBill1: IconDefinition;
export const faMoneyBillAlt: IconDefinition;
export const faCloudBolt: IconDefinition;
export const faThunderstorm: IconDefinition;
export const faEthernet: IconDefinition;
export const faHryvniaSign: IconDefinition;
export const faHryvnia: IconDefinition;
export const faEyeSlash: IconDefinition;
export const faCartFlatbedSuitcase: IconDefinition;
export const faLuggageCart: IconDefinition;
export const faRadiation: IconDefinition;
export const faFileWord: IconDefinition;
export const faBedPulse: IconDefinition;
export const faProcedures: IconDefinition;
export const faTents: IconDefinition;
export const faMugHot: IconDefinition;
export const faBolt: IconDefinition;
export const faZap: IconDefinition;
export const faJar: IconDefinition;
export const faTruckPlane: IconDefinition;
export const faHandHoldingHeart: IconDefinition;
export const faArrowRotateLeft: IconDefinition;
export const faArrowLeftRotate: IconDefinition;
export const faArrowRotateBack: IconDefinition;
export const faArrowRotateBackward: IconDefinition;
export const faUndo: IconDefinition;
export const faFaceAngry: IconDefinition;
export const faAngry: IconDefinition;
export const faBurst: IconDefinition;
export const faZ: IconDefinition;
export const faBandage: IconDefinition;
export const faBandAid: IconDefinition;
export const faPlaneCircleExclamation: IconDefinition;
export const faBusSide: IconDefinition;
export const faBugs: IconDefinition;
export const faBeerMugEmpty: IconDefinition;
export const faBeer: IconDefinition;
export const faPersonCircleCheck: IconDefinition;
export const faStapler: IconDefinition;
export const faHouseMedicalCircleCheck: IconDefinition;
export const faNairaSign: IconDefinition;
export const faWifi: IconDefinition;
export const faWifi3: IconDefinition;
export const faWifiStrong: IconDefinition;
export const faMoneyCheckDollar: IconDefinition;
export const faMoneyCheckAlt: IconDefinition;
export const faEyeLowVision: IconDefinition;
export const faLowVision: IconDefinition;
export const faCircleArrowUp: IconDefinition;
export const faArrowCircleUp: IconDefinition;
export const faCameraRetro: IconDefinition;
export const faCapsules: IconDefinition;
export const faPoo: IconDefinition;
export const faVolume: IconDefinition;
export const faVolumeMedium: IconDefinition;
export const faElevator: IconDefinition;
export const faTag: IconDefinition;
export const faFileCircleMinus: IconDefinition;
export const faDownLong: IconDefinition;
export const faLongArrowAltDown: IconDefinition;
export const faCompactDisc: IconDefinition;
export const faSuitcaseRolling: IconDefinition;
export const faBookQuran: IconDefinition;
export const faQuran: IconDefinition;
export const faPhoneSlash: IconDefinition;
export const faRoadCircleCheck: IconDefinition;
export const faShopLock: IconDefinition;
export const faImagePortrait: IconDefinition;
export const faPortrait: IconDefinition;
export const faBridgeLock: IconDefinition;
export const faHammer: IconDefinition;
export const faArrowUp19: IconDefinition;
export const faSortNumericUp: IconDefinition;
export const faChessKnight: IconDefinition;
export const faHouseFloodWaterCircleArrowRight: IconDefinition;
export const faArrowUpRightFromSquare: IconDefinition;
export const faExternalLink: IconDefinition;
export const faArrowDownUpAcrossLine: IconDefinition;
export const faFaceGrinBeam: IconDefinition;
export const faGrinBeam: IconDefinition;
export const faRectangleAd: IconDefinition;
export const faAd: IconDefinition;
export const faBookTanakh: IconDefinition;
export const faTanakh: IconDefinition;
export const faHotTubPerson: IconDefinition;
export const faHotTub: IconDefinition;
export const faFileHalfDashed: IconDefinition;
export const faOutdent: IconDefinition;
export const faDedent: IconDefinition;
export const faHandPeace: IconDefinition;
export const faHeadSideVirus: IconDefinition;
export const faCompass: IconDefinition;
export const faPenNib: IconDefinition;
export const faTentArrowsDown: IconDefinition;
export const faForwardFast: IconDefinition;
export const faFastForward: IconDefinition;
export const faCrop: IconDefinition;
export const faWhiskeyGlass: IconDefinition;
export const faGlassWhiskey: IconDefinition;
export const faSquare: IconDefinition;
export const faFaceGrin: IconDefinition;
export const faGrin: IconDefinition;
export const faFileContract: IconDefinition;
export const faAngleUp: IconDefinition;
export const faFaceSmile: IconDefinition;
export const faSmile: IconDefinition;
export const faPersonDressBurst: IconDefinition;
export const faDivide: IconDefinition;
export const faCodeFork: IconDefinition;
export const faHouseFlag: IconDefinition;
export const faBuildingColumns: IconDefinition;
export const faBank: IconDefinition;
export const faInstitution: IconDefinition;
export const faMuseum: IconDefinition;
export const faUniversity: IconDefinition;
export const faRug: IconDefinition;
export const faCodeMerge: IconDefinition;
export const faHouseTsunami: IconDefinition;
export const faMagnifyingGlassChart: IconDefinition;
export const faUmbrella: IconDefinition;
export const faHillRockslide: IconDefinition;
export const faUserSecret: IconDefinition;
export const faPager: IconDefinition;
export const faBriefcase: IconDefinition;
export const faTrowelBricks: IconDefinition;
export const faSocks: IconDefinition;
export const faT: IconDefinition;
export const faMicrochip: IconDefinition;
export const faTruckMedical: IconDefinition;
export const faAmbulance: IconDefinition;
export const faOm: IconDefinition;
export const faMosquitoNet: IconDefinition;
export const faPrescriptionBottle: IconDefinition;
export const faUsersGear: IconDefinition;
export const faUsersCog: IconDefinition;
export const faRoadCircleExclamation: IconDefinition;
export const faPause: IconDefinition;
export const faStaffSnake: IconDefinition;
export const faRodAsclepius: IconDefinition;
export const faRodSnake: IconDefinition;
export const faStaffAesculapius: IconDefinition;
export const faPiggyBank: IconDefinition;
export const faMonument: IconDefinition;
export const faAnglesRight: IconDefinition;
export const faAngleDoubleRight: IconDefinition;
export const faDesktop: IconDefinition;
export const faDesktopAlt: IconDefinition;
export const faPlaneCircleXmark: IconDefinition;
export const faRetweet: IconDefinition;
export const faUserGear: IconDefinition;
export const faUserCog: IconDefinition;
export const faBorderAll: IconDefinition;
export const faCoins: IconDefinition;
export const faMarsStroke: IconDefinition;
export const faHandshakeAngle: IconDefinition;
export const faHandsHelping: IconDefinition;
export const faArrowDown: IconDefinition;
export const faLocationDot: IconDefinition;
export const faMapMarkerAlt: IconDefinition;
export const faPlugCircleExclamation: IconDefinition;
export const faCookieBite: IconDefinition;
export const faScrewdriverWrench: IconDefinition;
export const faTools: IconDefinition;
export const faIndent: IconDefinition;
export const faBars: IconDefinition;
export const faNavicon: IconDefinition;
export const faHandsPraying: IconDefinition;
export const faPrayingHands: IconDefinition;
export const faViruses: IconDefinition;
export const faSchoolFlag: IconDefinition;
export const faTrademark: IconDefinition;
export const faFireBurner: IconDefinition;
export const faFaceSmileBeam: IconDefinition;
export const faSmileBeam: IconDefinition;
export const faTentArrowLeftRight: IconDefinition;
export const faRoute: IconDefinition;
export const faAnglesUp: IconDefinition;
export const faAngleDoubleUp: IconDefinition;
export const faBucket: IconDefinition;
export const faLessThanEqual: IconDefinition;
export const faFolderClosed: IconDefinition;
export const faPersonThroughWindow: IconDefinition;
export const faSchoolLock: IconDefinition;
export const faPersonBurst: IconDefinition;
export const faLeftLong: IconDefinition;
export const faLongArrowAltLeft: IconDefinition;
export const faLocationCrosshairs: IconDefinition;
export const faLocation: IconDefinition;
export const faPersonDotsFromLine: IconDefinition;
export const faDiagnoses: IconDefinition;
export const faGaugeSimpleHigh: IconDefinition;
export const faTachometer: IconDefinition;
export const faTachometerFast: IconDefinition;
export const faAnglesLeft: IconDefinition;
export const faAngleDoubleLeft: IconDefinition;
export const faUpDown: IconDefinition;
export const faArrowsAltV: IconDefinition;
export const faBatteryEmpty: IconDefinition;
export const faBattery0: IconDefinition;
export const faKeyboard: IconDefinition;
export const faCookie: IconDefinition;
export const faStopwatch: IconDefinition;
export const faEject: IconDefinition;
export const faSatelliteDish: IconDefinition;
export const faFaceRollingEyes: IconDefinition;
export const faMehRollingEyes: IconDefinition;
export const faListCheck: IconDefinition;
export const faTasks: IconDefinition;
export const faSackXmark: IconDefinition;
export const faHashtag: IconDefinition;
export const faTrain: IconDefinition;
export const faGamepad: IconDefinition;
export const faFileExport: IconDefinition;
export const faArrowRightFromFile: IconDefinition;
export const faFaceGrimace: IconDefinition;
export const faGrimace: IconDefinition;
export const faTrainSubway: IconDefinition;
export const faSubway: IconDefinition;
export const faCircleDot: IconDefinition;
export const faDotCircle: IconDefinition;
export const faObjectGroup: IconDefinition;
export const faShip: IconDefinition;
export const faC: IconDefinition;
export const faSquarePhone: IconDefinition;
export const faPhoneSquare: IconDefinition;
export const faRulerCombined: IconDefinition;
export const faArrowsRotate: IconDefinition;
export const faRefresh: IconDefinition;
export const faSync: IconDefinition;
export const faPersonDress: IconDefinition;
export const faFemale: IconDefinition;
export const faBookOpen: IconDefinition;
export const faFolderTree: IconDefinition;
export const faVirgo: IconDefinition;
export const faBoxArchive: IconDefinition;
export const faArchive: IconDefinition;
export const faTentArrowDownToLine: IconDefinition;
export const faQrcode: IconDefinition;
export const faDragon: IconDefinition;
export const faHourglassEnd: IconDefinition;
export const faHourglass3: IconDefinition;
export const faGrip: IconDefinition;
export const faGridHorizontal: IconDefinition;
export const faGripHorizontal: IconDefinition;
export const faBorderTopLeft: IconDefinition;
export const faBorderStyle: IconDefinition;
export const faListUl: IconDefinition;
export const faListDots: IconDefinition;
export const faPeopleRobbery: IconDefinition;
export const faMobileButton: IconDefinition;
export const faArrowDownAZ: IconDefinition;
export const faSortAlphaAsc: IconDefinition;
export const faSortAlphaDown: IconDefinition;
export const faMoneyBill: IconDefinition;
export const faCircleMinus: IconDefinition;
export const faMinusCircle: IconDefinition;
export const faArrowPointer: IconDefinition;
export const faMousePointer: IconDefinition;
export const faSquareShareNodes: IconDefinition;
export const faShareAltSquare: IconDefinition;
export const faTableCellsLarge: IconDefinition;
export const faThLarge: IconDefinition;
export const faCat: IconDefinition;
export const faCalendarWeek: IconDefinition;
export const faCodeCompare: IconDefinition;
export const faLeo: IconDefinition;
export const faRoadCircleXmark: IconDefinition;
export const faPallet: IconDefinition;
export const faCakeCandles: IconDefinition;
export const faBirthdayCake: IconDefinition;
export const faCake: IconDefinition;
export const faBugSlash: IconDefinition;
export const faTarp: IconDefinition;
export const faDiagramPredecessor: IconDefinition;
export const faFaceFlushed: IconDefinition;
export const faFlushed: IconDefinition;
export const faDiagramNext: IconDefinition;
export const faAnchorCircleXmark: IconDefinition;
export const faPersonCircleXmark: IconDefinition;
export const faSpa: IconDefinition;
export const faAries: IconDefinition;
export const faBarsProgress: IconDefinition;
export const faTasksAlt: IconDefinition;
export const faHeartCircleCheck: IconDefinition;
export const faMarsStrokeRight: IconDefinition;
export const faMarsStrokeH: IconDefinition;
export const faTowerObservation: IconDefinition;
export const faSterlingSign: IconDefinition;
export const faGbp: IconDefinition;
export const faPoundSign: IconDefinition;
export const faFaucetDrip: IconDefinition;
export const faCircleInfo: IconDefinition;
export const faInfoCircle: IconDefinition;
export const faFeather: IconDefinition;
export const faBowlRice: IconDefinition;
export const faStarHalfStroke: IconDefinition;
export const faStarHalfAlt: IconDefinition;
export const faTemperatureArrowDown: IconDefinition;
export const faTemperatureDown: IconDefinition;
export const faMaskVentilator: IconDefinition;
export const faFileVideo: IconDefinition;
export const faArrowTrendDown: IconDefinition;
export const faOilCan: IconDefinition;
export const faPeopleCarryBox: IconDefinition;
export const faPeopleCarry: IconDefinition;
export const faChair: IconDefinition;
export const faWind: IconDefinition;
export const faLayerGroup: IconDefinition;
export const faHeadSideMask: IconDefinition;
export const faHands: IconDefinition;
export const faSignLanguage: IconDefinition;
export const faSigning: IconDefinition;
export const faTablets: IconDefinition;
export const faWeightHanging: IconDefinition;
export const faDice: IconDefinition;
export const faShopSlash: IconDefinition;
export const faStoreAltSlash: IconDefinition;
export const faSortDown: IconDefinition;
export const faSortDesc: IconDefinition;
export const faPesetaSign: IconDefinition;
export const faTabletScreenButton: IconDefinition;
export const faTabletAlt: IconDefinition;
export const faHandHoldingDollar: IconDefinition;
export const faHandHoldingUsd: IconDefinition;
export const faShield: IconDefinition;
export const faShieldBlank: IconDefinition;
export const faFaceLaugh: IconDefinition;
export const faLaugh: IconDefinition;
export const faHandsHolding: IconDefinition;
export const faCartShopping: IconDefinition;
export const faShoppingCart: IconDefinition;
export const faOctagon: IconDefinition;
export const faHandPointer: IconDefinition;
export const faRegistered: IconDefinition;
export const faHouseSignal: IconDefinition;
export const faBangladeshiTakaSign: IconDefinition;
import { IconDefinition, IconLookup, IconName, IconPrefix, IconPack } from '@fortawesome/fontawesome-common-types';
export { IconDefinition, IconLookup, IconName, IconPrefix, IconPack } from '@fortawesome/fontawesome-common-types';
export const prefix: IconPrefix;
export const fas: IconPack;