import { IconDefinition, IconPrefix, IconName } from "@fortawesome/fontawesome-common-types";
export const definition: IconDefinition;
export const faBoxesAlt: IconDefinition;
export const prefix: IconPrefix;
export const iconName: IconName;
export const width: number;
export const height: number;
export const ligatures: (string | number)[];
export const unicode: string;
export const svgPathData: string;
export const aliases: (string | number)[];