export const faSquareMinus: IconDefinition;
export const faMinusSquare: IconDefinition;
export const faCalendarCheck: IconDefinition;
export const faFaceKiss: IconDefinition;
export const faKiss: IconDefinition;
export const faPaste: IconDefinition;
export const faFileClipboard: IconDefinition;
export const faHandPointLeft: IconDefinition;
export const faFileExcel: IconDefinition;
export const faEnvelope: IconDefinition;
export const faSquareCaretDown: IconDefinition;
export const faCaretSquareDown: IconDefinition;
export const faTruck: IconDefinition;
export const faBell: IconDefinition;
export const faMessage: IconDefinition;
export const faCommentAlt: IconDefinition;
export const faFaceDizzy: IconDefinition;
export const faDizzy: IconDefinition;
export const faCalendarDays: IconDefinition;
export const faCalendarAlt: IconDefinition;
export const faHandPointUp: IconDefinition;
export const faHandLizard: IconDefinition;
export const faSquareFull: IconDefinition;
export const faCirclePause: IconDefinition;
export const faPauseCircle: IconDefinition;
export const faHardDrive: IconDefinition;
export const faHdd: IconDefinition;
export const faFileZipper: IconDefinition;
export const faFileArchive: IconDefinition;
export const faFloppyDisk: IconDefinition;
export const faSave: IconDefinition;
export const faFaceGrinTongueSquint: IconDefinition;
export const faGrinTongueSquint: IconDefinition;
export const faCamera: IconDefinition;
export const faCameraAlt: IconDefinition;
export const faFaceGrinStars: IconDefinition;
export const faGrinStars: IconDefinition;
export const faEye: IconDefinition;
export const faFaceSadTear: IconDefinition;
export const faSadTear: IconDefinition;
export const faShareFromSquare: IconDefinition;
export const faShareSquare: IconDefinition;
export const faNoteSticky: IconDefinition;
export const faStickyNote: IconDefinition;
export const faHandBackFist: IconDefinition;
export const faHandRock: IconDefinition;
export const faChessQueen: IconDefinition;
export const faFaceGrinTears: IconDefinition;
export const faGrinTears: IconDefinition;
export const faPenToSquare: IconDefinition;
export const faEdit: IconDefinition;
export const faFaceGrinBeamSweat: IconDefinition;
export const faGrinBeamSweat: IconDefinition;
export const faClock: IconDefinition;
export const faClockFour: IconDefinition;
export const faFaceLaughWink: IconDefinition;
export const faLaughWink: IconDefinition;
export const faPaperPlane: IconDefinition;
export const faHeart: IconDefinition;
export const faFontAwesome: IconDefinition;
export const faFontAwesomeFlag: IconDefinition;
export const faFontAwesomeLogoFull: IconDefinition;
export const faClone: IconDefinition;
export const faFolderOpen: IconDefinition;
export const faWindowMinimize: IconDefinition;
export const faStarHalf: IconDefinition;
export const faAlarmClock: IconDefinition;
export const faNewspaper: IconDefinition;
export const faHospital: IconDefinition;
export const faHospitalAlt: IconDefinition;
export const faHospitalWide: IconDefinition;
export const faCircleStop: IconDefinition;
export const faStopCircle: IconDefinition;
export const faObjectUngroup: IconDefinition;
export const faComment: IconDefinition;
export const faChessPawn: IconDefinition;
export const faCalendarPlus: IconDefinition;
export const faClipboard: IconDefinition;
export const faThumbsDown: IconDefinition;
export const faIdBadge: IconDefinition;
export const faSquareCheck: IconDefinition;
export const faCheckSquare: IconDefinition;
export const faChessBishop: IconDefinition;
export const faEnvelopeOpen: IconDefinition;
export const faCircleXmark: IconDefinition;
export const faTimesCircle: IconDefinition;
export const faXmarkCircle: IconDefinition;
export const faSquareCaretUp: IconDefinition;
export const faCaretSquareUp: IconDefinition;
export const faFileImage: IconDefinition;
export const faSquareCaretRight: IconDefinition;
export const faCaretSquareRight: IconDefinition;
export const faSun: IconDefinition;
export const faImage: IconDefinition;
export const faLightbulb: IconDefinition;
export const faAddressCard: IconDefinition;
export const faContactCard: IconDefinition;
export const faVcard: IconDefinition;
export const faFaceMeh: IconDefinition;
export const faMeh: IconDefinition;
export const faMap: IconDefinition;
export const faHandPointDown: IconDefinition;
export const faFaceMehBlank: IconDefinition;
export const faMehBlank: IconDefinition;
export const faFaceGrinTongue: IconDefinition;
export const faGrinTongue: IconDefinition;
export const faFutbol: IconDefinition;
export const faFutbolBall: IconDefinition;
export const faSoccerBall: IconDefinition;
export const faFaceSurprise: IconDefinition;
export const faSurprise: IconDefinition;
export const faFolder: IconDefinition;
export const faFolderBlank: IconDefinition;
export const faCloud: IconDefinition;
export const faCircle: IconDefinition;
export const faFaceGrinSquint: IconDefinition;
export const faGrinSquint: IconDefinition;
export const faCircleUser: IconDefinition;
export const faUserCircle: IconDefinition;
export const faRectangleList: IconDefinition;
export const faListAlt: IconDefinition;
export const faHand: IconDefinition;
export const faHandPaper: IconDefinition;
export const faThumbsUp: IconDefinition;
export const faBuilding: IconDefinition;
export const faChessRook: IconDefinition;
export const faCircleQuestion: IconDefinition;
export const faQuestionCircle: IconDefinition;
export const faFile: IconDefinition;
export const faFaceSadCry: IconDefinition;
export const faSadCry: IconDefinition;
export const faCalendarMinus: IconDefinition;
export const faFaceTired: IconDefinition;
export const faTired: IconDefinition;
export const faHandPointRight: IconDefinition;
export const faCircleUp: IconDefinition;
export const faArrowAltCircleUp: IconDefinition;
export const faHandScissors: IconDefinition;
export const faGem: IconDefinition;
export const faRectangleXmark: IconDefinition;
export const faRectangleTimes: IconDefinition;
export const faTimesRectangle: IconDefinition;
export const faWindowClose: IconDefinition;
export const faTrashCan: IconDefinition;
export const faTrashAlt: IconDefinition;
export const faLifeRing: IconDefinition;
export const faCopyright: IconDefinition;
export const faCircleLeft: IconDefinition;
export const faArrowAltCircleLeft: IconDefinition;
export const faCalendar: IconDefinition;
export const faFaceFrownOpen: IconDefinition;
export const faFrownOpen: IconDefinition;
export const faChartBar: IconDefinition;
export const faBarChart: IconDefinition;
export const faHouse: IconDefinition;
export const faHome: IconDefinition;
export const faHomeAlt: IconDefinition;
export const faHomeLgAlt: IconDefinition;
export const faFaceFrown: IconDefinition;
export const faFrown: IconDefinition;
export const faUser: IconDefinition;
export const faUserAlt: IconDefinition;
export const faUserLarge: IconDefinition;
export const faSnowflake: IconDefinition;
export const faBookmark: IconDefinition;
export const faSquareCaretLeft: IconDefinition;
export const faCaretSquareLeft: IconDefinition;
export const faHandshake: IconDefinition;
export const faHandshakeAlt: IconDefinition;
export const faHandshakeSimple: IconDefinition;
export const faFaceSmileWink: IconDefinition;
export const faSmileWink: IconDefinition;
export const faFaceGrinSquintTears: IconDefinition;
export const faGrinSquintTears: IconDefinition;
export const faFileAudio: IconDefinition;
export const faCalendarXmark: IconDefinition;
export const faCalendarTimes: IconDefinition;
export const faCircleDown: IconDefinition;
export const faArrowAltCircleDown: IconDefinition;
export const faFileLines: IconDefinition;
export const faFileAlt: IconDefinition;
export const faFileText: IconDefinition;
export const faComments: IconDefinition;
export const faCircleCheck: IconDefinition;
export const faCheckCircle: IconDefinition;
export const faMoon: IconDefinition;
export const faClosedCaptioning: IconDefinition;
export const faImages: IconDefinition;
export const faCircleRight: IconDefinition;
export const faArrowAltCircleRight: IconDefinition;
export const faIdCard: IconDefinition;
export const faDriversLicense: IconDefinition;
export const faCirclePlay: IconDefinition;
export const faPlayCircle: IconDefinition;
export const faFaceLaughBeam: IconDefinition;
export const faLaughBeam: IconDefinition;
export const faAddressBook: IconDefinition;
export const faContactBook: IconDefinition;
export const faHourglass: IconDefinition;
export const faHourglassEmpty: IconDefinition;
export const faHeadphones: IconDefinition;
export const faHeadphonesAlt: IconDefinition;
export const faHeadphonesSimple: IconDefinition;
export const faFilePowerpoint: IconDefinition;
export const faWindowMaximize: IconDefinition;
export const faCommentDots: IconDefinition;
export const faCommenting: IconDefinition;
export const faFaceGrinTongueWink: IconDefinition;
export const faGrinTongueWink: IconDefinition;
export const faHourglassHalf: IconDefinition;
export const faHourglass2: IconDefinition;
export const faCreditCard: IconDefinition;
export const faCreditCardAlt: IconDefinition;
export const faHandSpock: IconDefinition;
export const faBellSlash: IconDefinition;
export const faStar: IconDefinition;
export const faFlag: IconDefinition;
export const faLemon: IconDefinition;
export const faWindowRestore: IconDefinition;
export const faFaceGrinHearts: IconDefinition;
export const faGrinHearts: IconDefinition;
export const faFaceKissBeam: IconDefinition;
export const faKissBeam: IconDefinition;
export const faFilePdf: IconDefinition;
export const faFaceGrinWide: IconDefinition;
export const faGrinAlt: IconDefinition;
export const faFaceLaughSquint: IconDefinition;
export const faLaughSquint: IconDefinition;
export const faFaceKissWinkHeart: IconDefinition;
export const faKissWinkHeart: IconDefinition;
export const faCopy: IconDefinition;
export const faChessKing: IconDefinition;
export const faSquarePlus: IconDefinition;
export const faPlusSquare: IconDefinition;
export const faFileCode: IconDefinition;
export const faFaceGrinWink: IconDefinition;
export const faGrinWink: IconDefinition;
export const faMoneyBill1: IconDefinition;
export const faMoneyBillAlt: IconDefinition;
export const faEyeSlash: IconDefinition;
export const faFileWord: IconDefinition;
export const faFaceAngry: IconDefinition;
export const faAngry: IconDefinition;
export const faChessKnight: IconDefinition;
export const faFaceGrinBeam: IconDefinition;
export const faGrinBeam: IconDefinition;
export const faHandPeace: IconDefinition;
export const faCompass: IconDefinition;
export const faSquare: IconDefinition;
export const faFaceGrin: IconDefinition;
export const faGrin: IconDefinition;
export const faFaceSmile: IconDefinition;
export const faSmile: IconDefinition;
export const faFaceSmileBeam: IconDefinition;
export const faSmileBeam: IconDefinition;
export const faFolderClosed: IconDefinition;
export const faKeyboard: IconDefinition;
export const faFaceRollingEyes: IconDefinition;
export const faMehRollingEyes: IconDefinition;
export const faFaceGrimace: IconDefinition;
export const faGrimace: IconDefinition;
export const faCircleDot: IconDefinition;
export const faDotCircle: IconDefinition;
export const faObjectGroup: IconDefinition;
export const faFaceFlushed: IconDefinition;
export const faFlushed: IconDefinition;
export const faStarHalfStroke: IconDefinition;
export const faStarHalfAlt: IconDefinition;
export const faFileVideo: IconDefinition;
export const faFaceLaugh: IconDefinition;
export const faLaugh: IconDefinition;
export const faHandPointer: IconDefinition;
export const faRegistered: IconDefinition;
import { IconDefinition, IconLookup, IconName, IconPrefix, IconPack } from '@fortawesome/fontawesome-common-types';
export { IconDefinition, IconLookup, IconName, IconPrefix, IconPack } from '@fortawesome/fontawesome-common-types';
export const prefix: IconPrefix;
export const far: IconPack;